# Tests if value is in an array. Assumes that values do not appear
# as substrings in other values.
#
# Usage: in_array "value" MY_ARRAY
function in_array() {
  local -r value=$1
  local -n values=$2 || exit "${EXIT_CODE_INTERNAL_ERROR}"
  if [[ ! " ${values[*]} " == *" ${value} "* ]]; then
    return 1
  fi
}

# Prints difference of arg1 and arg2.
#
# Usage (prints only non-farm animals):
#   result=($( difference ANIMALS FARM_ANIMALS ))
#
# (note: passing arrays by reference)
function difference() {
  local -n values="$1"
  local -n filter="$2"

  comm -23 <(printf '%s\n' "${values[@]}" | sort -u) <(printf '%s\n' "${filter[@]}" | sort -u)
}

# Prints intersection of arg1 and arg2.
#
# Usage (prints only farm animals):
#   result=($( intersection ANIMALS FARM_ANIMALS ))
#
# (note: passing arrays by reference)
function intersection() {
  local -n values="$1"
  local -n filter="$2"

  comm -12 <(printf '%s\n' "${values[@]}" | sort -u) <(printf '%s\n' "${filter[@]}" | sort -u)
}

# Prints union of arg1 and arg2 with duplicates removed.
#
# Usage:
#   result=($( union PETS CATTLE ))
#
# (note: passing arrays by reference)
function union() {
  local -n v1="$1"
  local -n v2="$2"

  printf "%s\n" "${v1[@]}" "${v2[@]}" | sort -u
}
