if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
  source "${BDUTIL_DIR}/image_config/s8s-spark-${DATAPROC_IMAGE_VERSION}.sh"
else
  source "${BDUTIL_DIR}/image_config/${DATAPROC_IMAGE_VERSION}.sh"
fi

# Hardcode $PATH for initialization, since the system path may include
# unexpected dependencies (such as python = Python 3) on custom images.
if [[ "${PATH}" == *:/snap/bin* ]]; then
  # In Ubuntu, gcloud and gsutil are under /snap/bin.
  PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/snap/bin
else
  PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
fi

DATAPROC_DIR="/usr/local/share/google/dataproc"
DATAPROC_TMP_DIR="/tmp/dataproc"
DATAPROC_COMMON_LIB_DIR="${DATAPROC_DIR}/lib"
# Directory holding downloaded artifacts which override the default ones, e.g.,
# startup script.
DATAPROC_ARTIFACTS_DIR="${DATAPROC_DIR}/artifacts"
DATAPROC_CONF_DIR="${DATAPROC_DIR}/conf"
DATAPROC_METADATA_CONF="${DATAPROC_CONF_DIR}/dataproc_metadata.sh"

# Dir used to track the status of background processes.
COMMANDS_TMP_DIR="${DATAPROC_TMP_DIR}/commands"

## Maven repo mirror to directly download artifacts wherever necessary.
readonly OSS_MAVEN_REPO=https://maven-central.storage-download.googleapis.com/maven2

# Components
# Dir used to track the status of component scripts.
DATAPROC_COMPONENTS_TMP_DIR="${DATAPROC_TMP_DIR}/components"
# Script generated by startup-script.sh that stores which components should be
# activated in POST_HDFS_ENV variable that is later sourced by
# post-hdfs-startup-script.sh. The agent runs post-hdfs-startup-script.sh in a
# separate process and the env variables exported in startup-script.sh will
# not be available in that process.
POST_HDFS_ENV="${BDUTIL_DIR}/components/post_hdfs_env.sh"

# Metadata from the config file takes precedence over that from the VM
# metadata. Config file is typically used when running on Kubernetes, because we
# want to get metadata for the Pod instead of metadata for the node VM. In this
# case the config file will be first written in a ConfigMap, then mounted into
# the Pod by the control plane.
if [[ -f "${DATAPROC_METADATA_CONF}" ]]; then
  source "${DATAPROC_METADATA_CONF}"
fi

INSTALL_GCS_CONNECTOR=1      # true
INSTALL_BIGQUERY_CONNECTOR=1 # true
ENABLE_HDFS=1                # true
HADOOP_INSTALL_DIR='/usr/lib/hadoop'
HADOOP_LIB_DIR="${HADOOP_INSTALL_DIR}/lib"
HADOOP_CONF_DIR='/etc/hadoop/conf'
HADOOP_MASTER_MAPREDUCE_MEMORY_FRACTION=0.4
HDFS_MASTER_MEMORY_FRACTION=0.4
NODEMANAGER_MEMORY_FRACTION=0.8
NUM_WORKERS=10 # Needed by Teragen
WORKERS=()
CORES_PER_MAP_TASK=1.0
CORES_PER_REDUCE_TASK=2.0
CORES_PER_APP_MASTER=2.0
HDFS_DATA_DIRS_PERM='700'

# Spark
SPARK_CONF_DIR="/etc/spark/conf"
SPARK_WORKER_MEMORY_FRACTION='0.8'
SPARK_EXECUTOR_MEMORY_FRACTION='0.8'
SPARK_DAEMON_MEMORY_FRACTION='0.15'
SPARK_EXECUTORS_PER_VM=2

# Tez
TEZ_CONF_DIR='/etc/tez/conf'
TEZ_LIB_DIR='/usr/lib/tez'

# Miniconda3
MINICONDA3_INSTALL_PATH="/opt/conda/miniconda3"
MINICONDA3_BIN_DIR="${MINICONDA3_INSTALL_PATH}/bin"

# Bigtable HBase Client for usage with ATSv2
if [[ -v BIGTABLE_HBASE_CLIENT_VERSION ]]; then
  BIGTABLE_HBASE_CLIENT_JAR="${BIGTABLE_HBASE_CLIENT_JAR_PREFIX}-${BIGTABLE_HBASE_CLIENT_VERSION}.jar"
  BIGTABLE_HBASE_CONF_DIR="/etc/bigtable-hbase/conf"
fi

# Collectd plugin generation
HDFS_METRIC_SOURCE="hdfs"
HIVESERVER2_METRIC_SOURCE="hiveserver2"
HIVEMETASTORE_METRIC_SOURCE="hivemetastore"
MONITORING_AGENT_DEFAULTS_SOURCE="monitoringAgentDefaults"
SPARK_HISTORY_SERVER_METRIC_SOURCE="sparkHistoryServer"
SPARK_METRIC_SOURCE="spark"
YARN_METRIC_SOURCE="yarn"
FLINK_METRIC_SOURCE="flink"

HDFS_COLLECTD_CONF_FILE_NAME="collectd_hdfs_jmx_metrics.conf"
HIVESERVER2_COLLECTD_CONF_FILE_NAME="collectd_hiveserver2_jmx_metrics.conf"
HIVEMETASTORE_COLLECTD_CONF_FILE_NAME="collectd_hivemetastore_jmx_metrics.conf"
SPARK_HISTORY_SERVER_COLLECTD_CONF_FILE_NAME="collectd_shs_jmx_metrics.conf"
if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
  SPARK_COLLECTD_CONF_FILE_NAME="collectd_spark_standalone_metrics.conf"
else
  SPARK_COLLECTD_CONF_FILE_NAME="collectd_spark_yarn_metrics.conf"
fi
YARN_COLLECTD_CONF_FILE_NAME="collectd_yarn_jmx_metrics.conf"
PROCESSES_DEFAULT_METRICS_CONF_FILE_NAME="collectd_processes_default_metrics.conf"
SPARK_DEFAULT_METRICS_CONF_FILE_NAME="collectd_spark_default_metrics.conf"
FLINK_COLLECTD_CONF_FILE_NAME="collectd_flink_statsd_metrics.conf"

COLLECTD_CONF_FILE_NAMES=(
  $HDFS_COLLECTD_CONF_FILE_NAME
  $HIVESERVER2_COLLECTD_CONF_FILE_NAME
  $HIVEMETASTORE_COLLECTD_CONF_FILE_NAME
  $SPARK_HISTORY_SERVER_COLLECTD_CONF_FILE_NAME
  $SPARK_COLLECTD_CONF_FILE_NAME
  $YARN_COLLECTD_CONF_FILE_NAME
  $FLINK_COLLECTD_CONF_FILE_NAME
  )

function get_metric_source_to_file_name_kwargs() {
  local -r args=(
    "${HDFS_METRIC_SOURCE}=${HDFS_COLLECTD_CONF_FILE_NAME}"
    "${HIVESERVER2_METRIC_SOURCE}=${HIVESERVER2_COLLECTD_CONF_FILE_NAME}"
    "${HIVEMETASTORE_METRIC_SOURCE}=${HIVEMETASTORE_COLLECTD_CONF_FILE_NAME}"
    "${SPARK_HISTORY_SERVER_METRIC_SOURCE}=${SPARK_HISTORY_SERVER_COLLECTD_CONF_FILE_NAME}"
    "${SPARK_METRIC_SOURCE}=${SPARK_COLLECTD_CONF_FILE_NAME}"
    "${YARN_METRIC_SOURCE}=${YARN_COLLECTD_CONF_FILE_NAME}"
    "${FLINK_METRIC_SOURCE}=${FLINK_COLLECTD_CONF_FILE_NAME}"
  )
   echo "${args[@]}"
}
