# Verifies that GCS bucket can be accessed.
function check_gcs_bucket_access() {
  local -r gcs_path=$1
  local -r component=${2:-startup-script}

  if [[ "${gcs_path}" == "gs://"* ]]; then
    local bucket
    bucket=$(echo "${gcs_path}" | sed -E "s/(gs:\/\/[^/]+).*/\1/")
    local message
    if ! message=$(env BOTO_CONFIG="" gsutil ls "${bucket}/" 2>&1); then
      log_and_fail "${component}" "${message}"
    fi
  fi
}

# Checks if a file exists in GCS.
function gcs_file_exists() {
  local -r file=$1
  result=$(gsutil -q stat "$file" || echo 1)
  if [[ $result != 1 ]]; then
    return 0
  else
    return 1
  fi
}

# Checks if path exists in GCS.
#
# Note that there might not be an object for the path, e.g., there is only one
# object `gs://bucket/dir/foo`, no such object as `gs://my-bucket/dir` or
# `gs://my-bucket/dir/`, in this case `gsutil stat gs://my-bucket/dir` will
# fail, but this function will succeed.
function check_gcs_path_exists() {
  local -r path=$1
  gsutil ls "${path}" >/dev/null 2>&1
}

# Decrypts a GCS file with a KMS key and prints the result to STDOUT.
function decrypt_file_with_kms_key() {
  local -r encrypted_file_uri="$1"
  local -r kms_key_uri="$2"

  gsutil cat "${encrypted_file_uri}" | gcloud kms decrypt \
    --ciphertext-file - --plaintext-file - --key "${kms_key_uri}"
}

# GCS copy with retry and metadata preserved.
#
# Wildcard can be used as src and dir can be used as dst.
function gcs_copy_with_metadata_preserved() {
  local -r src="$1"
  local -r dst="$2"

  # -P to preserve modification timestamp, see b/197509557
  retry_constant_custom 30 5 gsutil -m cp -P "${src}" "${dst}"
}

# GCS rsync with retry and metadata preserved.
function gcs_rsync_with_metadata_preserved() {
  local -r src_dir="$1"
  local -r dst_dir="$2"

  # -P to preserve modification timestamp, see b/197509557
  retry_constant_custom 30 5 gsutil -m rsync -r -P "${src_dir}" "${dst_dir}"
}