# Gets Dataproc metadata (e.g., cluster node role) value from env variable or VM
# metadata.
function get_dataproc_metadata() {
  set +x
  local -r var_name="$1"
  local -r attr_name="$2"
  if [[ -v "${var_name}" ]]; then
    echo "${!var_name}"
  else
    /usr/share/google/get_metadata_value "$attr_name"
  fi
  set -x
}

function get_metadata_project_id() {
  get_dataproc_metadata "DATAPROC_METADATA_PROJECT_ID" "../project/project-id"
}

# Dataproc region which could be "global".
function get_metadata_dataproc_region() {
  get_dataproc_metadata "DATAPROC_METADATA_REGION" "attributes/dataproc-region"
}

function get_metadata_zone() {
  local zone_uri
  zone_uri=$(get_dataproc_metadata "DATAPROC_METADATA_ZONE" "zone")
  echo "${zone_uri##*/}"
}

function get_metadata_bucket() {
  get_dataproc_metadata "DATAPROC_METADATA_BUCKET" "attributes/dataproc-bucket"
}

function get_metadata_temp_bucket() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_TEMP_BUCKET" "attributes/dataproc-temp-bucket"
}

function get_metadata_role() {
  get_dataproc_metadata "DATAPROC_METADATA_ROLE" "attributes/dataproc-role"
}

function get_metadata_cluster_name() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_CLUSTER_NAME" "attributes/dataproc-cluster-name"
}

function get_metadata_cluster_uuid() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_CLUSTER_UUID" "attributes/dataproc-cluster-uuid"
}

function get_metadata_worker_count() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_WORKER_COUNT" "attributes/dataproc-worker-count"
}

function get_metadata_master() {
  get_dataproc_metadata "DATAPROC_METADATA_MASTER" "attributes/dataproc-master"
}

function get_metadata_master_additional() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_MASTER_ADDITIONAL" \
    "attributes/dataproc-master-additional"
}

function get_metadata_datanode_enabled() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_DATANODE_ENABLED" \
    "attributes/dataproc-datanode-enabled"
}

function get_metadata_gcs_connector_version() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_GCS_CONNECTOR_VERSION" \
    "attributes/GCS_CONNECTOR_VERSION"
}

function get_metadata_gcs_connector_url() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_GCS_CONNECTOR_URL" \
    "attributes/GCS_CONNECTOR_URL"
}

function get_metadata_spark_bq_connector_version() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_SPARK_BQ_CONNECTOR_VERSION" \
    "attributes/SPARK_BQ_CONNECTOR_VERSION"
}

function get_metadata_spark_bq_connector_url() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_SPARK_BQ_CONNECTOR_URL" \
    "attributes/SPARK_BQ_CONNECTOR_URL"
}

function get_metadata_spark_rapids_use_default_jars() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_SPARK_RAPIDS_USE_DEFAULT_JARS" \
    "attributes/SPARK_RAPIDS_USE_DEFAULT_JARS"
}

function get_metadata_hive_metastore_instance() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_HIVE_METASTORE_INSTANCE" \
    "attributes/hive-metastore-instance"
}

function get_metadata_filesystem_scheme() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_FILESYSTEM_SCHEME" "attributes/filesystem-scheme"
}

function get_metadata_agent_jvm_args() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_AGENT_JVM_ARGS" \
    "attributes/cloud-dataproc-agent-jvm-args"
}

function get_metadata_agent_jar_location() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_AGENT_JAR_LOCATION" \
    "attributes/cloud-dataproc-agent-jar"
}

function get_metadata_startup_script_location() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_STARTUP_SCRIPT_LOCATION" \
    "attributes/cloud-dataproc-startup-script"
}

function get_metadata_post_hdfs_startup_script_location() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_POST_HDFS_STARTUP_SCRIPT_LOCATION" \
    "attributes/cloud-dataproc-post-hdfs-startup-script"
}

function get_metadata_instance_scopes() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_INSTANCE_SCOPES" "service-accounts/default/scopes"
}

function get_metadata_batch_id() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_BATCH_ID" "attributes/dataproc-batch-id"
}

function get_metadata_batch_uuid() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_BATCH_UUID" "attributes/dataproc-batch-uuid"
}

function get_metadata_session_id() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_SESSION_ID" "attributes/dataproc-session-id"
}

function get_metadata_session_uuid() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_SESSION_UUID" "attributes/dataproc-session-uuid"
}

function get_metadata_dataproc_lineage_enabled() {
  get_dataproc_metadata \
    "DATAPROC_METADATA_LINEAGE_ENABLED" "attributes/DATAPROC_LINEAGE_ENABLED"
}

# Check weather instance has proper scope to work with a GCP service
# Provide enough granular scope to check if instance has that scope
# e.g. for checking cloud-platform scope, provide auth/cloud-platform
function instance_has_scope() {
  local -r scope=$1
  local instance_scopes
  instance_scopes=$(get_metadata_instance_scopes)
  if echo "${instance_scopes}" | grep -q "https://www.googleapis.com/${scope}"; then
    return 0
  fi
  return 1
}

function get_auth_token() {
  /usr/share/google/get_metadata_value service-accounts/default/token |
    jq -r '.access_token'
}
