# Compares version strings. Returns true if $1 >= $2
# Usage: is_at_least_version "1.2.3" "1.2.0" (returns true)
function is_version_at_least() {
  # Disable debug logs (if enabled) to not pollute logs with verbose output
  local reenable_x=false
  if [[ -o xtrace ]]; then
    set +x
    reenable_x=true
  fi

  # Suppress leading 'vs'
  local -r version1="${1#v}"
  local -r version2="${2#v}"

  (compare_versions "$version1" "$version2")
  local -r compare_versions_result=$?
  # Only renable dbug logs if necessary
  if [[ "${reenable_x}" == "true" ]]; then
    set -x
  fi
  case ${compare_versions_result} in
    0) return 0;;
    1) return 0;;
    2) return 1;;
  esac
  return 2  # For strings which are not in valid version format
}

# Method to validate whether an input string is in dot-separated version format
# or not, returns 0 for valid format and 1 otherwise.
function validate_version() {
  local -r version=$1
  local -r re='^[0-9]+(\.[0-9]+)*$'
  if [[ $version =~ $re ]]; then
    return 0
  fi
  return 1
}

# Method to compare two strings in dot-separated version format
# https://stackoverflow.com/a/4025065
function compare_versions() {
  local -r version1=$1
  local -r version2=$2
  if ! validate_version "$version1"; then
    echo "Invalid format for $version1"
    return 3
  fi
  if ! validate_version "$version2"; then
    echo "Invalid format for $version2"
    return 3
  fi

  if [[ "$version1" == "$version2" ]]; then
    return 0
  fi

  local IFS=.
  local i ver1=($version1) ver2=($version2)

  # fill empty fields in ver1 with zeros
  for ((i=${#ver1[@]}; i<${#ver2[@]}; i++)); do
    ver1[i]=0
  done

  for ((i=0; i<${#ver1[@]}; i++)); do
    if [[ -z ${ver2[i]} ]]; then
      # fill empty fields in ver2 with zeros
      ver2[i]=0
    fi

    if ((10#${ver1[i]} > 10#${ver2[i]})); then
      return 1
    fi

    if ((10#${ver1[i]} < 10#${ver2[i]})); then
      return 2
    fi
  done
  return 0
}
