#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_services.sh"
source "$(dirname "$0")/../shared/earlyoom.sh"
source "${DATAPROC_DIR}/dataproc_env.sh"

set -x

function configure_earlyoom() {
  local -r earlyoom_log_file="/var/log/earlyoom.log"
  # On workers, prefer killing java process with application id and container id in the command
  local -r prefer_regex="^.*java[[:space:]].*application[_0-9]+[^[:space:]]+container[_0-9]+.*"

  local earlyoom_threshold
  if [[ "${ROLE}" == 'Master' ]]; then
    earlyoom_threshold="$(get_dataproc_property_or_default 'internal.node.main.memory-protection.threshold.kib' 65536)"
    cat >"${earlyoom_config_file}" <<EOF
EARLYOOM_ARGS="-r 15 -M ${earlyoom_threshold} -s 1 -l ${earlyoom_log_file}"
EOF
  elif [[ "${ROLE}" == 'Worker' ]]; then
    earlyoom_threshold="$(get_dataproc_property_or_default 'internal.node.main.memory-protection-worker.threshold.kib' 65536)"
    cat >"${earlyoom_config_file}" <<EOF
EARLYOOM_ARGS="-r 15 -M ${earlyoom_threshold} -s 1 -l ${earlyoom_log_file} --prefer ${prefer_regex}"
EOF
  elif [[ "${ROLE}" == 'Driver' ]]; then
    earlyoom_threshold="$(get_dataproc_property_or_default 'internal.node.main.memory-protection-driver.threshold.kib' 65536)"
    cat >"${earlyoom_config_file}" <<EOF
EARLYOOM_ARGS="-r 15 -M ${earlyoom_threshold} -s 1 -l ${earlyoom_log_file}"
EOF
  fi

  # NPD and fluentd tail logs from this file. They may fail to start if this
  # file doesn't exist.
  touch ${earlyoom_log_file}
  chmod a+rw ${earlyoom_log_file}
}

function main() {
  local -r earlyoom_config_file="/etc/default/earlyoom"

  if is_earlyoom_enabled; then
    configure_earlyoom
    enable_and_start_service earlyoom
  fi
}

main
