#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_networking.sh"
source "$(dirname "$0")/../../bdutil_metadata.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_services.sh"
source "$(dirname "$0")/../shared/hive.sh"
source "$(dirname "$0")/../shared/hive-metastore.sh"

set -x

HIVE_CONF_DIR="/etc/hive/conf"

ROLE="$(get_metadata_role)"
DATAPROC_MASTER="$(get_metadata_master)"

function wait_for_mysql() {
  # Wait until we can connect to the mysql server on port 3306 of master 0,
  # which is where the underlying metastore database is.
  # This usually doesn't succeed until around the eighth attempt.
  wait_for_port "mysql" "${DATAPROC_MASTER}" 3306
}

function start_hive_metastore() {
  enable_service hive-metastore
  retry_constant systemctl restart hive-metastore
}

function activate_hive_metastore() {
  if [[ "${ROLE}" == "Master" ]]; then
    wait_for_mysql
    start_hive_metastore
    wait_for_hive_metastore
  else
    echo "Skip running Hive metastore on ${ROLE} node ${HOSTNAME}"
  fi
}

activate_hive_metastore
