#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../shared/nfs.sh"
source "${DATAPROC_DIR}/dataproc_env.sh"

set -x

function enable_rpcbind() {
  systemctl enable rpcbind.service rpcbind.socket rpcbind.target
}

function get_allowed_hosts_pattern() {
  local my_hostname
  my_hostname=$(hostname -s)
  local prefix="${my_hostname%-m}"

  local allowed_pattern
  allowed_pattern=$(get_java_property_or_default \
    "${SPARK_CONF_DIR}/spark-defaults.conf" \
    'spark.dataproc.nfs.allowedHostPattern' "${prefix}*")
  echo "${allowed_pattern}"
}

function start_nfs() {
  # Rpcbind is disabled for serverless workload by default. So we need to enable it
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
    enable_rpcbind
  fi

  # Start the nfs server on the master node
  if [[ "${ROLE}" == "Master" ]]; then
    local allowed_pattern
    allowed_pattern=$(get_allowed_hosts_pattern)
    # TODO: encrypt NFS traffic
    cat >>"/etc/exports" <<EOF
${NFS_MOUNT_PATH} ${allowed_pattern}(rw,sync,no_subtree_check)
EOF

    # TODO: forward nfs daemon logs to cloud logging.
    retry_constant_short systemctl enable nfs-kernel-server
    retry_constant_short systemctl start nfs-kernel-server
  elif [[ "${ROLE}" == "Worker" ]] ; then
    retry_constant_short mount "${MASTER_HOSTNAME_0}:${NFS_MOUNT_PATH}" "${NFS_MOUNT_PATH}"
  fi
}

start_nfs