#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_metrics.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_services.sh"
source "$(dirname "$0")/../shared/earlyoom.sh"

set -x

function create_systemd_service() {
  local -r service_path="$1"
  local -r npd_config_args="$2"

  cat >"${service_path}"<<EOF
[Unit]
Description=Node Problem Detector
[Service]
User=root
WorkingDirectory=/usr/local/bin
ExecStart=/usr/local/bin/npd --logtostderr ${npd_config_args}
Restart=on-failure
RestartSec=5

[Install]
WantedBy=multi-user.target
EOF
}

function configure_npd() {
  local -r yarn_job_metrics_enabled=$1
  local -r yarn_nm_metrics_enabled=$2

  # Configure NPD for systemctl
  local -r init_script="/etc/systemd/system/npd.service"
  local -r config_dir="${DATAPROC_DIR}/npd-config"

  local npd_configs=()

  # Enable stackdriver
  npd_configs+=("--stackdriver-config=${config_dir}/exporter/stackdriver-exporter.json")

  # Enable system stat monitors
  npd_configs+=("--config.system-stats-monitor=${config_dir}/system-stats-monitor.json,${config_dir}/net-cgroup-system-stats-monitor.json")

   # Enable YARN job/application monitor
   if [[ "${yarn_job_metrics_enabled}" == "true" ]]; then
     local yarn_job_monitor_config_file="yarn-rm-monitor"
     if is_component_selected 'kerberos'; then
       yarn_job_monitor_config_file+="-kerberos"
     fi

     npd_configs+=("--config.yarn-monitor=${config_dir}/${yarn_job_monitor_config_file}.json")
   fi

   # Enable YARN NodeManager monitor
   if [[ "${yarn_nm_metrics_enabled}" == "true" ]]; then
     local yarn_nm_monitor_config_file="yarn-nm-monitor"

     if is_component_selected 'kerberos'; then
       yarn_nm_monitor_config_file+="-kerberos"
     fi

     npd_configs+=("--config.yarn-monitor=${config_dir}/${yarn_nm_monitor_config_file}.json")
   fi

  # Enable EarlyOOM monitor
  if is_earlyoom_enabled; then
    local -r earlyoom_log_file="/var/log/earlyoom.log"
    # NPD will fail to start if this file doesn't exist.
    touch ${earlyoom_log_file}
    chmod a+rw ${earlyoom_log_file}

    npd_configs+=("--config.system-log-monitor=${config_dir}/earlyoom-monitor.json")
  fi

  create_systemd_service "${init_script}" "${npd_configs[*]}"

  chmod a+rw "${init_script}"

  systemctl daemon-reload
  enable_and_start_service npd
}

if is_default_system_metrics_enabled; then
  configure_npd \
    "$(get_dataproc_property dataproc.monitoring.job.yarn.metrics.enable)" \
    "$(get_dataproc_property dataproc.metrics.node.yarn.nodemanager.health.enable)"
fi