#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_networking.sh"
source "$(dirname "$0")/../../bdutil_metadata.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_services.sh"
source "$(dirname "$0")/../../bdutil_versions.sh"
source "$(dirname "$0")/../shared/rubix.sh"
source "${DATAPROC_DIR}/dataproc_env.sh"

set -x

ROLE="$(get_metadata_role)"
readonly ROLE

function start_rubix_service() {
  local is_master="True"

  if [[ "${ROLE}" != "Master" ]]; then
    is_master="False"
  fi

  local -r service_name="rubix"
  local -r exec_start="${RUBIX_HOME_DIR}/bin/rubix.service start ${is_master}"
  local -r exec_stop="${RUBIX_HOME_DIR}/bin/rubix.service stop ${is_master}"

  cat >"/etc/systemd/system/${service_name}.service" <<EOF
[Unit]
Description=Rubix ${ROLE}
Wants=network-online.target
After=network-online.target

[Service]
User=root
Group=root
Type=forking
ExecStart=${exec_start}
ExecStop=${exec_stop}
Restart=on-failure
OOMScoreAdjust=0

[Install]
WantedBy=multi-user.target
EOF

  mkdir -p /var/run/rubix
  chown root:root /var/run/rubix
  chmod 775 /var/run/rubix

  retry_constant_short systemctl daemon-reload
  retry_constant_short systemctl enable "${service_name}"
  retry_constant_short systemctl start "${service_name}"
}

start_rubix_service
