#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_helpers.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"

set -x

function install_earlyoom() {
  local -r earlyoom_dir="$(mktemp -d)"
  local -r temp_log="$(mktemp)"
  local -r tmp_home="$(mktemp -d)"

  git clone \
    https://gerrit.googlesource.com/gcompute-tools \
    "${tmp_home}"
  HOME="${tmp_home}" "${tmp_home}/git-cookie-authdaemon" > "${temp_log}"
  HOME="${tmp_home}" git clone \
    --depth 1 \
    --branch dataproc-tag-1.7-1 \
    'https://bigdataoss-internal.googlesource.com/third_party/rfjakob/earlyoom' \
    "${earlyoom_dir}"
  process_id=$(cat "${temp_log}" | cut -f 3 -d " ")
  kill -9 "${process_id}"

  cd "${earlyoom_dir}"
  make earlyoom

  cp "${earlyoom_dir}/earlyoom" "${DATAPROC_DIR}"
  chmod a+rx "${DATAPROC_DIR}/earlyoom"
  ln -s "${DATAPROC_DIR}/earlyoom" /usr/local/bin/earlyoom

  rm -Rf "${earlyoom_dir}" "${tmp_home}" "${temp_log}"
}

function configure_earlyoom_unit() {
  local -r unit_file="/etc/systemd/system/earlyoom.service"

  cat >"${unit_file}" <<"EOF"
[Unit]
Description=Early OOM Daemon

[Service]
User=root
EnvironmentFile=-/etc/default/earlyoom
ExecStart=/usr/local/bin/earlyoom $EARLYOOM_ARGS
DynamicUser=true
AmbientCapabilities=CAP_KILL CAP_IPC_LOCK
Nice=-20
OOMScoreAdjust=-100
ProtectSystem=strict
ReadWritePaths=/var/log/
ProtectHome=true
Restart=always
TasksMax=10
MemoryMax=50M

[Install]
WantedBy=multi-user.target
EOF

  systemctl daemon-reload
  systemctl disable earlyoom
}

# Configure logrotate to rotate /var/log/earlyoom.log
function configure_logrotate() {
  local -r logrotate_config_file="/etc/logrotate.d/earlyoom"

  # Trigger rotation when file size is larger than 200MB.
  # Compress and keep 5 old logs.
  # Ignore /var/log/earlyoom.log if it doesn't exist.
  cat >"${logrotate_config_file}" <<EOF
/var/log/earlyoom.log {
  rotate 5
  size 200M
  compress
  missingok
}
EOF
}

install_earlyoom
configure_earlyoom_unit
configure_logrotate


