#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_misc.sh"
source "$(dirname "$0")/../../bdutil_networking.sh"
source "$(dirname "$0")/../shared/proxy-agent.sh"

set -x

function install_npd() {
  local -r download_dir="$(mktemp -d)"
  local arch_suffix
  arch_suffix="$(get_arch_suffix)"
  local -r download_source="https://golang.org/dl/go1.18.8.linux-${arch_suffix}.tar.gz"
  local -r download_location="${download_dir}/go1.18.8.linux-${arch_suffix}.tar.gz"

  download_resource "${download_source}" "${download_location}"

  tar -C "${download_dir}" -zxf "${download_location}"

  local -r npd_dir="$(mktemp -d)"
  local -r cache_dir="$(mktemp -d)"
  local -r temp_log="$(mktemp)"
  local -r HOME="$(mktemp -d)"

  (
    export HOME &&
    git clone https://gerrit.googlesource.com/gcompute-tools &&
    gcompute-tools/git-cookie-authdaemon > "${temp_log}"  &&
    git clone \
      --single-branch \
      --branch dataproc-branch-0.1 \
      'https://bigdataoss-internal.googlesource.com/third_party/kubernetes/node-problem-detector' \
      "${npd_dir}" &&
    process_id=$(cat "${temp_log}" | cut -f 3 -d " ")
    kill -9 "${process_id}" &&

    export GOPATH="${download_dir}/go" &&
    cd "${npd_dir}" &&
    GOCACHE="${cache_dir}" make GOLANG_BIN="${download_dir}/go/bin/go"
  )

  local bin_output="bin/node-problem-detector"
  if [[ "${arch_suffix}" == 'arm64' ]]; then
    bin_output="output/linux_arm64/bin/node-problem-detector"
  fi

  cp "${npd_dir}/${bin_output}" "${DATAPROC_DIR}/npd"
  cp -r "${npd_dir}/config" "${DATAPROC_DIR}/npd-config"
  chmod a+rx "${DATAPROC_DIR}/npd"
  ln -s "${DATAPROC_DIR}/npd" /usr/local/bin/npd

  rm -Rf "gcompute-tools" "${npd_dir}" "${cache_dir}" "${download_dir}" "${HOME}" "${temp_log}"
}

install_npd