#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_networking.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"

set -x

function install_kernel_modules() {
  local -r modules_tar="open-gpu-kernel-modules-${NVIDIA_GPU_VERSION}.tar.gz"
  local download_dir
  download_dir="$(mktemp -d)"
  local -r download_location="${download_dir}/${modules_tar}"

  download_resource \
    "gs://dataproc-image-dependencies/nvidia/${modules_tar}" \
    "${download_location}"

  local kernel_headers
  mapfile -t kernel_headers < <(find /usr/src/ -name "linux-headers-*-cloud-amd64")
  if [[ ${#kernel_headers[@]} != 1 ]]; then
    log_and_fail 'nvidia-drivers' \
      "Found more than one Linux kernel header: ${kernel_headers[*]}"
  fi
  local -r kernel_uname="${kernel_headers[*]##*/linux-headers-}"

  pushd "${download_dir}"
  tar -xzf "${download_location}" --strip-components=1
  make modules "-j$(nproc)" "KERNEL_UNAME=${kernel_uname}"
  make modules_install "-j$(nproc)" "KERNEL_UNAME=${kernel_uname}" \
    TARGET_ARCH=x86_64
  popd

  rm -rf "${download_dir}"
}

function install_drivers() {
  local -r installer_name="NVIDIA-Linux-x86_64-${NVIDIA_GPU_VERSION}.run"
  local -r installer="/tmp/${installer_name}"

  download_resource \
    "gs://dataproc-image-dependencies/nvidia/${installer_name}" \
    "${installer}"

  sh "${installer}" -s --dkms --no-kernel-modules --install-libglvnd
  depmod -a

  rm -f "${installer}"
}

function download_licenses() {
  mkdir -p "${DATAPROC_DIR}/licenses"
  local -r license_url="https://download.nvidia.com/XFree86/Linux-x86_64/${NVIDIA_GPU_VERSION}/license.txt"

  download_resource \
    "${license_url}" "${DATAPROC_DIR}/licenses/NVIDIA_DRIVER_LICENSE"
}

install_kernel_modules
install_drivers
download_licenses
