#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_helpers.sh"

set -x

os_install_packages \
  hadoop-yarn-resourcemanager \
  hadoop-yarn-nodemanager ||
  err "Failed to install YARN packages"

systemctl disable hadoop-yarn-resourcemanager.service hadoop-yarn-nodemanager.service

# Used by YARN Timeline Service v2
function install_yarn_atsv2_dependencies() {
  install_golang_binary "cloud.google.com/go/cbt@latest"

  download_resource \
    "gs://maven-central/maven2/com/google/cloud/bigtable/${BIGTABLE_HBASE_CLIENT_JAR_PREFIX}/${BIGTABLE_HBASE_CLIENT_VERSION}/${BIGTABLE_HBASE_CLIENT_JAR}" \
    "${DATAPROC_COMMON_LIB_DIR}/${BIGTABLE_HBASE_CLIENT_JAR}"
}

install_yarn_atsv2_dependencies


# TODO: Remove this when this is fixed in Bigtop.
function disable_noisy_timeline_server_logs() {
  CUSTOM_LOGGING_PROPS_FILE=/etc/hadoop/conf/yarn-timelineserver.logging.properties
  cat >"${CUSTOM_LOGGING_PROPS_FILE}" <<EOF
com.sun.jersey.server.wadl.generators.WadlGeneratorJAXBGrammarGenerator.level=OFF
EOF

  cat >>/etc/hadoop/conf/yarn-env.sh <<EOF
export YARN_TIMELINESERVER_OPTS="\${YARN_TIMELINESERVER_OPTS} -Djava.util.logging.config.file=${CUSTOM_LOGGING_PROPS_FILE}"
EOF
}

function disable_cgroup_v2() {
  local cgroup_params="systemd.unified_cgroup_hierarchy=false systemd.legacy_systemd_cgroup_controller=false"
  sed -ie "s/^GRUB_CMDLINE_LINUX=\"\(.*\)\"/GRUB_CMDLINE_LINUX=\"\1 ${cgroup_params}\"/" /etc/default/grub
  if is_debian || is_ubuntu ; then
    update-grub
  elif is_rocky; then
    grub2-mkconfig -o /boot/grub2/grub.cfg
  fi
}

disable_noisy_timeline_server_logs

if is_debian12 || is_debian11 || is_ubuntu22 || is_rocky9; then
  disable_cgroup_v2
fi
