#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_metadata.sh"
source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_gcs.sh"
source "$(dirname "$0")/../../bdutil_versions.sh"
source "$(dirname "$0")/../../bdutil_misc.sh"
source "$(dirname "$0")/../shared/ranger.sh"
source "$(dirname "$0")/../shared/ranger_gcs_plugin.sh"

set -x

function post_hdfs_ranger() {
  cd "${RANGER_INSTALL_DIR}"

  if [[ "${ROLE}" == 'Master' && "${NODE_NAME}" =~ ^.*(-m|-m-0)$ ]]; then
    run_ranger_admin
    add_usersync_plugin
    add_hdfs_plugin
    add_hive_plugin
    add_yarn_plugin
    if is_component_selected "presto"; then
        add_presto_plugin
    fi
  fi

  # In HA clusters Namenode is installed also on m-1. We also need to install and configure
  # ranger hdfs plugin on m-1.
  if [[ "${ROLE}" == 'Master' && "${NODE_NAME}" =~ ^.*(-m-1)$ ]]; then
    add_hdfs_plugin
  fi

  # In HA clusters ResourceManager is installed also on m-1 and m-2.
  # We also need to install and configure ranger yarn plugin on additional masters.
  if [[ "${ROLE}" == 'Master' && "${NODE_NAME}" =~ ^.*(-m-1|-m-2)$ ]]; then
    add_hive_plugin
    add_yarn_plugin
    if is_component_selected "presto"; then
        add_presto_plugin
    fi
  fi

  # Install Ranger GCS plugin on master node(s)
  if [[ "$(get_dataproc_property 'ranger.gcs.plugin.enable')" == 'true' ]]; then
    # Ranger admin is only installed on m-0 master node in HA mode.
    if [[ "${ROLE}" == 'Master' && "${NODE_NAME}" =~ ^.*(-m|-m-0)$ ]]; then
      register_ranger_gcs_service_to_ranger_admin
      create_ranger_gcs_plugin_iam_roles
    fi
    install_ranger_gcs_plugin_authorization_service
    install_ranger_gcs_plugin_client
  fi
}

post_hdfs_ranger
