#!/bin/bash

# Script that starts spark-history-server on first boot after HDFS is functional.
# The script is only run on master nodes.

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../../bdutil_services.sh"
source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../shared/hdfs.sh"
source "$(dirname "$0")/../shared/spark.sh"

set -x
readonly IS_COMPONENT_GATEWAY_HA_ENABLED=$(get_dataproc_property_or_default dataproc:componentgateway.ha.enabled false)

# If spark.eventLog.dir is set to the in-cluster HDFS (which is NOT the
# default), create the dir here after HDFS is ready.
function create_event_log_dir_in_cluster_hdfs() {
  local event_log_dir
  event_log_dir=$(get_java_property \
    "${SPARK_CONF_DIR}/spark-defaults.conf" spark.eventLog.dir)

  if is_in_cluster_hdfs "${event_log_dir}"; then
    create_hdfs_dir "${event_log_dir}" spark:spark 755

    # Spark history server ignores disabled permissions and somehow makes
    # the event log dir 770
    retry_constant_short sudo -u hdfs \
        hadoop fs -chgrp spark "${event_log_dir}"
  fi
}

if [[ "${ROLE}" == "Master" ]] &&
[[ "${IS_COMPONENT_GATEWAY_HA_ENABLED}" == "true"  || "${MASTER_INDEX?}" == "0" ]]; then
  create_event_log_dir_in_cluster_hdfs
  start_spark_history_server
fi
