#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_helpers.sh"
source "$(dirname "$0")/../shared/mysql.sh"
source "$(dirname "$0")/../shared/hive.sh"

set -x

set_log_tag "post-install-component-hive-metastore"

function configure_hive_metastore() {
  ln -s /usr/share/java/mysql.jar /usr/lib/hive/lib/

  # Sneakily configure MySQL before shutting it down.
  # Wildcard % allows connections from all hosts.
  set +x

  HIVE_PASSWD="$(random_password)"
  export HIVE_PASSWD
  mysql -u root "-p${MYSQL_DEFAULT_ROOT_PASSWORD}" -e " \
      CREATE DATABASE metastore; \
      CREATE USER 'hive'@'%' IDENTIFIED BY '${HIVE_PASSWD}'; \
      GRANT ALL PRIVILEGES ON metastore.* TO 'hive'@'%'; \
      FLUSH PRIVILEGES;"
  set -x

  bdconfig merge_configurations \
    --configuration_file /etc/hive/conf/hive-site.xml \
    --source_configuration_file "${BDUTIL_DIR}/conf/hive-template.xml" \
    --resolve_environment_variables \
    --create_if_absent \
    --clobber

  bdconfig set_property \
    --configuration_file "/etc/hive/conf/hive-site.xml" \
    --name "javax.jdo.option.ConnectionPassword" \
    --value "${HIVE_PASSWD}" \
    --clobber


  configure_hive_gc "metastore"

  # TODO: Fix in BigTop
  # delete Log4j2 bindings for Slf4j to prevent warning in Hive
  rm -f /usr/lib/hive/lib/log4j-slf4j-impl*.jar

  /usr/lib/hive/bin/schematool -dbType mysql -initSchema
}

function disable_mysql_on_startup() {
  systemctl stop "${MYSQL_SERVICE}"
  systemctl disable "${MYSQL_SERVICE}"
}

function disable_hive_metastore_on_startup() {
  systemctl stop hive-metastore
  systemctl disable hive-metastore
}

configure_hive_metastore
disable_hive_metastore_on_startup
disable_mysql_on_startup
