#!/bin/bash

set -euox pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../shared/pig.sh"

function update_log_properties() {
  cp "${PIG_CONF_DIR}"/log4j.properties.template "${PIG_CONF_DIR}"/log4j.properties
}

function update_pig_properties() {
  # point the hcat.bin property to /usr/bin/hcat 
  cat >> "${PIG_CONF_DIR}/pig.properties" <<EOF

hcat.bin=/usr/bin/hcat

tez.lib.uris.classpath=/usr/lib/tez/*\:/usr/lib/tez/lib/*
tez.lib.uris=file\:///usr/lib/tez

log4jconf=/etc/pig/conf/log4j.properties

EOF
}

function create_pig_env_script() {
  # Setup pig env script to enable using hCatalog with Pig
  pig_env_script="${PIG_CONF_DIR}/pig-env.sh"

  cat << EOF | tee "${pig_env_script}"
#!/bin/bash

includeHCatalog=true

EOF
}

function create_pig_tez_sym_link() {
  # Add symlink as tez requires tez-site.xml to be available in PIG_CLASSPATH
  # to ensure pig jobs and actions are visible in Tez UI properly i.e.
  # ${PIG_CONF_DIR}/tez-site.xml --> ${TEZ_CONF_DIR}/tez-site.xml
  ln -s "${TEZ_CONF_DIR}/tez-site.xml" "${PIG_CONF_DIR}/tez-site.xml"

}

create_pig_env_script
create_pig_tez_sym_link
update_pig_properties
update_log_properties
