#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_gcs.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_metadata.sh"
source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../shared/hive-metastore.sh"

set -x

set_log_tag "pre-activate-component-hive-metastore"

HIVE_CONF_DIR="/etc/hive/conf"
CLUSTER_PROPERTIES_DIR="/tmp/cluster/properties"

bdconfig set_property \
  --configuration_file /etc/hive/conf/hive-site.xml \
  --name 'hive.metastore.uris' \
  --value "${CLUSTER_MASTER_METASTORE_URIS}" \
  --clobber

if ! is_component_selected "hdfs"; then
  bdconfig set_property \
    --configuration_file /etc/hive/conf/hive-site.xml \
    --name 'hive.metastore.warehouse.dir' \
    --value "${HCFS_ROOT_URI}/hive/warehouse/" \
    --clobber
fi

HIVE_WAREHOUSE_DIR=$(get_property_in_xml /etc/hive/conf/hive-site.xml \
  hive.metastore.warehouse.dir)

# Check that HIVE warehouse bucket exists and can be accessed.
if [[ "${HIVE_WAREHOUSE_DIR}" == "gs://"* ]]; then
  check_gcs_bucket_access "${HIVE_WAREHOUSE_DIR}"
fi


# Always talk to the mysql server on master 0.
# TODO: Once we've configured master-master active-passive
# replication, change connect string to incorporate load balancing that fails
# over to passive if active unreachable.
METADATASTORE_JDBC_URI="jdbc:mysql://${DATAPROC_MASTER}/metastore"

bdconfig set_property \
  --configuration_file /etc/hive/conf/hive-site.xml \
  --name 'javax.jdo.option.ConnectionURL' \
  --value "${METADATASTORE_JDBC_URI}" \
  --clobber
