#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_env.sh"
source "$(dirname "$0")/../../bdutil_logging.sh"
source "$(dirname "$0")/../../bdutil_properties.sh"
source "$(dirname "$0")/../../bdutil_components.sh"
source "$(dirname "$0")/../../bdutil_versions.sh"
source "$(dirname "$0")/../../bdutil_retry.sh"
source "$(dirname "$0")/../shared/rubix.sh"
source "${DATAPROC_DIR}/dataproc_env.sh"

set -x

set_log_tag "pre-activate-component-rubix"

readonly RUBIX_SPARK_JARS="${RUBIX_HOME_DIR}/lib/*"

function initialize_cache_directories() {
  local -i num_local_ssd=$1
  if [[ ${num_local_ssd} -gt 0 ]]; then
    mkdir -p "${RUBIX_CACHE_DIR}"
    for (( i=0; i<num_local_ssd; i++ )) ; do
      mkdir -p "/mnt/$((${i}+1))/rubix"
      # Create symlink with localssd
      ln -s "/mnt/$((${i}+1))/rubix" "${RUBIX_CACHE_DIR}/data${i}"
    done
  else
    echo "ERROR: No NVMe Local SSD attached with this cluster."
    echo "ERROR: Please recreate it with NVMe Local SSD attached to both master and worker"
    exit 1;
  fi
  echo "$(num_local_ssd)"
  return
}

function configure_rubix_conf() {
  # Create Rubix site
  local -i num_local_ssd=$1
  (cat <<CLIENT
<?xml version="1.0"?>
<configuration>
    <property>
        <name>rubix.cache.dirprefix.list</name>
        <value>${RUBIX_CACHE_DIR}/data</value>
    </property>

    <!-- Disable internal caching for FileSystem objects -->
    <property>
        <name>fs.gs.impl.disable.cache</name>
        <value>true</value>
    </property>
    <property>
        <name>rubix.cache.parallel.warmup</name>
        <value>false</value>
    </property>
    <property>
        <name>rubix.cache.max.disks</name>
        <value>${num_local_ssd}</value>
    </property>
</configuration>
CLIENT
  ) > "${RUBIX_SITE}"

  mkdir -p "/etc/rubix/"
  ln -s "${RUBIX_SITE}" /etc/rubix/rubix-site.xml

  local master_hostname
  master_hostname="$(bdconfig get_property_value \
                              --configuration_file "${HADOOP_CONF_DIR}/yarn-site.xml" \
                              --name "yarn.resourcemanager.hostname")"
  local -r master_hostname
  if [[ -z $master_hostname ]]; then
    echo "Master hostname was empty";
    exit 1;
  fi

  set_property_in_xml "${RUBIX_SITE}" "master.hostname" "${master_hostname}"
}

function configure_spark_for_rubix() {
  local -r spark_config_file="/etc/spark/conf/spark-defaults.conf"
  cat >>"${SPARK_CONF_DIR}/spark-env.sh" <<EOF

# Adding Dataproc caching Jars in classpath
export SPARK_DIST_CLASSPATH="\${SPARK_DIST_CLASSPATH}:${RUBIX_HOME_DIR}/lib/*"

EOF

  set_java_property \
    "${spark_config_file}" \
    "spark.hadoop.fs.gs.impl" \
    "${RUBIX_GOOGLE_CACHING_CLASS}" \
    "overwrite"
}

function setup() {
  local num_local_ssd
  num_local_ssd=$(get_localSsd_count)
  local -ir num_local_ssd
  initialize_cache_directories "${num_local_ssd}"
  configure_rubix_conf "${num_local_ssd}"
  configure_spark_for_rubix
}

setup
