source "${BDUTIL_DIR}/components/shared/conda.sh"

export EFFECTIVE_PYTHON_PROFILE="/etc/profile.d/effective-python.sh"

# Installs effective python profile depending on version and
# activated components.
#
# This function is safe to call from multiple components concurrently.
function install_effective_python_profile() {
  if [[ ! -f "${EFFECTIVE_PYTHON_PROFILE}" ]]; then
    generate_effective_python_profile
  fi
}

# Returns directory of the effective python.
# This will be a path such as /usr/bin or /opt/conda/bin
function get_effective_python_path() {
  # Assuming that anaconda/miniconda is symlinked.
  if is_component_selected "miniconda3"; then
    echo "${CONDA_HOME}/bin"
  elif is_component_selected "anaconda"; then
    echo "${CONDA_HOME}/bin"
  else
    echo "/usr/bin"
  fi
}

function generate_effective_python_profile() {
  if is_component_selected "miniconda3"; then
    source "$(dirname "$0")/../shared/miniconda3.sh"
    if [[ "${MINICONDA3_INSTALL_PATH}" != "${CONDA_HOME}" ]]; then
      ln -f -s "${MINICONDA3_INSTALL_PATH}" "${CONDA_HOME}"
    fi
  elif is_component_selected "anaconda"; then
    source "$(dirname "$0")/../shared/anaconda.sh"
    if [[ "${ANACONDA_INSTALL_PATH}" != "${CONDA_HOME}" ]]; then
      ln -f -s "${ANACONDA_INSTALL_PATH}" "${CONDA_HOME}"
    fi
  fi
  emit_conda_profile "${CONDA_HOME}"
}

function emit_conda_profile() {
  local -r conda_dir="$1"
  local -r python_bin="${conda_dir}/bin"

  local temp
  temp=$(mktemp)

  # Setup login shells for conda. This ensures you can open a shell and run
  # 'conda activate'.
  ln -f -s "${conda_dir}/etc/profile.d/conda.sh" /etc/profile.d/conda.sh
  chmod +x "${conda_dir}/etc/profile.d/conda.sh"

  cat >"${temp}" <<EOF
export PATH=${python_bin}:\${PATH}
export PYSPARK_PYTHON=${python_bin}/python
EOF

  mv -n -v "${temp}" "${EFFECTIVE_PYTHON_PROFILE}" || true
  chmod a+r "${EFFECTIVE_PYTHON_PROFILE}"
  rm -Rf "${temp}"
}
