source "$(dirname "$0")/../../bdutil_versions.sh"

# Install directories for Flink and Hadoop.
readonly FLINK_INSTALL_DIR='/usr/lib/flink'
readonly FLINK_WORKING_DIR='/var/lib/flink'
readonly FLINK_YARN_SCRIPT='/usr/bin/flink-yarn-daemon'
readonly HADOOP_CONF_DIR='/etc/hadoop/conf'

# Get worker memory from yarn config.
readonly WORKER_TOTAL_MEM="$(hdfs getconf \
    -confKey yarn.nodemanager.resource.memory-mb)"

# Memory used by the job manager (master) determined by the physical (free) memory of the server.
# Flink config entry: jobmanager.memory.process.size.
readonly FLINK_JOBMANAGER_MEMORY_FRACTION='.20'
readonly FLINK_JOBMANAGER_MIN_MEMORY_MB="1024"
readonly FLINK_JOBMANAGER_MAX_MEMORY_MB="4096"

# Memory used by the task managers (slaves) determined by the physical (free) memory of the servers.
# Flink config entry: taskmanager.memory.process.size.
readonly FLINK_TASKMANAGER_MEMORY_FRACTION='.20'
readonly FLINK_TASKMANAGER_MIN_MEMORY_MB="1024"
readonly FLINK_TASKMANAGER_MAX_MEMORY_MB="4096"

readonly START_FLINK_YARN_SESSION_METADATA_KEY='flink-start-yarn-session'
# Set this to true to start a flink yarn session at initialization time. For now
# disable it because we can provide both jobcluster and long running session
# cluster.
readonly START_FLINK_YARN_SESSION_DEFAULT=false

function err() {
  echo "[$(date +'%Y-%m-%dT%H:%M:%S%z')]: $*" >&2
  return 1
}

function calculate_flink_jm_tm_memory() {
  local -r component=$1
  if [[ "${component}" == "FLINK_JOBMANAGER" ]] ; then
    calculated_default_memory=$(python -c \
    "print(int(${WORKER_TOTAL_MEM} * ${FLINK_JOBMANAGER_MEMORY_FRACTION}))")
  else
    calculated_default_memory=$(python -c \
    "print(int(${WORKER_TOTAL_MEM} * ${FLINK_TASKMANAGER_MEMORY_FRACTION}))")
  fi
  local -r min_memory=$2
  local -r max_memory=$3

  #If calculated memory is not in the range of min,max. Replace it with min or max depending on the condition.
  if [[ "${calculated_default_memory}" -gt "${max_memory}" ]]; then
    echo "${max_memory}"
  elif [[ "${calculated_default_memory}" -lt "${min_memory}" ]]; then
    echo "${min_memory}"
  else
    echo "${calculated_default_memory}"
  fi
}
