#!/bin/bash

set -euo pipefail

source "$(dirname "$0")/../../bdutil_metadata.sh"

set -x

DATAPROC_MASTER=$(get_metadata_master)
DATAPROC_MASTER_ADDITIONAL=$(get_metadata_master_additional || true)
MASTER_HOSTNAMES=($DATAPROC_MASTER ${DATAPROC_MASTER_ADDITIONAL//,/ })
NUM_MASTERS=${#MASTER_HOSTNAMES[@]}
ROLE="$(get_metadata_role)"

# For hive high availability, configure multiple metastore servers.
if [[ $NUM_MASTERS -gt 1 ]]; then
  URIS_ARRAY=("${MASTER_HOSTNAMES[@]/#/thrift://}")
  URIS_ARRAY=("${URIS_ARRAY[@]/%/:9083}")
  CLUSTER_MASTER_METASTORE_URIS=$(tr ' ' ',' <<<"${URIS_ARRAY[@]}")
else
  CLUSTER_MASTER_METASTORE_URIS="thrift://${DATAPROC_MASTER}:9083"
fi

# Returns one of the Hive metastore URIs. Local metastore is preferred over
# remote metastores.
function get_hive_metastore_uri() {
  local uris_str
  uris_str=$(get_property_in_xml "${HIVE_CONF_DIR}/hive-site.xml" \
    hive.metastore.uris)
  local -a uris=(${uris_str//,/' '})
  for uri in "${uris[@]}"; do
    if [[ "${uri}" == *${HOSTNAME}* ]]; then
      echo "${uri}"
      return 0
    fi
  done
  if [[ "${uris_str}" == "" ]] && [[ "${ROLE}" == "Worker" ]]; then
    uris=("${CLUSTER_MASTER_METASTORE_URIS}")
  fi
  echo "${uris[0]}"
}

function wait_for_hive_metastore() {
  local timeout
  timeout=$(get_dataproc_property_or_default \
    startup.component.service-binding-timeout.hive-metastore 300)
  local metastore_uri
  metastore_uri="$(get_hive_metastore_uri)"
  local host
  host=$(echo "${metastore_uri}" | sed -n 's#.*://\(.*\):.*#\1#p')
  if [[ -z "${host}" ]]; then
    host="${HOSTNAME}"
  fi
  local port
  port=$(echo "${metastore_uri}" | sed -n 's#.*://.*:\(.*\)#\1#p')
  if [[ -z "${port}" ]]; then
    port=9083
  fi
  wait_for_port "hive-metastore" "${host}" "${port}" "${timeout}"
}
