source "$(dirname "$0")/../shared/hive-metastore.sh"

HIVE_CONF_DIR="/etc/hive/conf"


function start_hive_server2() {
  # The hive metastore (which could be on-cluster or remote) must be functional
  # in order for hive-server2 startup to succeed.
  wait_for_hive_metastore

  enable_service hive-server2

  # Start hive-server2.
  retry_constant systemctl start hive-server2

  # Wait until hive-server2 is actually responding on the thrift server port
  # (by default # `systemctl start/restart hive-server2` will return before
  # it's ready to serve traffic)
  local thrift_port
  thrift_port=$(get_property_in_xml "${HIVE_CONF_DIR}/hive-site.xml" \
    hive.server2.thrift.port 10000)
  local timeout
  timeout=$(get_dataproc_property_or_default \
    startup.component.service-binding-timeout.hive-server2 300)
  wait_for_port "hive-server2" "${HOSTNAME}" "${thrift_port}" "${timeout}"
}

# Set these JVM GC options for Hive server2 and metastore to avoid long GC
# pauses causing connection timeouts, see b/313767768.
#
# PrintGC* could produce useful debugging information, but could also be
# confusing to end-users when printed to stderr.
#
# HADOOP_CLIENT_OPTS executed by the hadoop jar command will override
# any HADOOP_OPTS. Provide opts to HADOOP_CLIENT_OPTS which will be used by
# the service JVM.
function configure_hive_gc() {
  local -r service="$1"

  local opts
  if is_version_at_least "${DATAPROC_IMAGE_VERSION}" "2.1"; then
    opts="-Xlog:gc*:stdout:time,level,tags"
  else
    opts="-XX:+UseConcMarkSweepGC -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails "
  fi

  cat >>/etc/hive/conf/hive-env.sh <<EOF

if [[ "\${SERVICE}" = "${service}" ]]; then
  export GC_OPTS="${opts} -XX:+ExitOnOutOfMemoryError "
  export HADOOP_CLIENT_OPTS="\${HADOOP_CLIENT_OPTS} \${GC_OPTS}"
fi
EOF
}