if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
  export CONDA_DIR="/opt/dataproc/conda"
  export JUPYTER_LOG_DIR="/var/log/jupyter"
else
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]] ||
      is_version_at_least "${DATAPROC_IMAGE_VERSION}" "2.0"; then
    export CONDA_DIR="/opt/conda/miniconda3"
  else
    export CONDA_DIR="/opt/conda/anaconda"
  fi
  export JUPYTER_LOG_DIR="/var/log"
fi

export CONDA_BIN_DIR="${CONDA_DIR}/bin"
export PATH="${CONDA_BIN_DIR}:${PATH}"

export JUPYTER_DATAPROC_DIR="/opt/dataproc/jupyter"

export JUPYTER_WHEEL="${JUPYTER_DATAPROC_DIR}/pip_wheel.whl"
export JUPYTER_EXTRA_PACKAGES="${JUPYTER_DATAPROC_DIR}/pip_wheel.requirements"
export JUPYTER_EXTRA_PACKAGES_DEPS="${JUPYTER_DATAPROC_DIR}/pip_wheel_deps.requirements"

export JUPYTER_ETC_DIR="/etc/jupyter"
export JUPYTER_ENV_FILE="/etc/default/jupyter"

export JUPYTER_CONFIG_FILE="${JUPYTER_ETC_DIR}/jupyter_notebook_config.py"

export JUPYTER_LOG_FILE="${JUPYTER_LOG_DIR}/jupyter_notebook.log"

# Reference: https://ipython.readthedocs.io/en/latest/install/kernel_install.html
export PYSPARK_KERNELSPEC="${CONDA_DIR}/share/jupyter/kernels/pyspark/kernel.json"
export R_KERNELSPEC="${CONDA_DIR}/share/jupyter/kernels/ir/kernel.json"

export JUPYTER_SYSTEMD_UNIT="/usr/lib/systemd/system/jupyter.service"

export JUPYTERHUB_SYSTEMD_UNIT="/usr/lib/systemd/system/jupyterhub.service"

export S8S_IPYTHON_PROFILE_LOCATION="/home/spark/.ipython/profile_default"

function create_ipython_profile() {
  # Create ipython profile
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
    "${CONDA_BIN_DIR}"/ipython profile create --profile-dir="${S8S_IPYTHON_PROFILE_LOCATION}"
  else
    "${CONDA_BIN_DIR}"/ipython profile create
  fi

  # Load google-cloud-bigquery when ipython starts
  local ipython_profile_location
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
    ipython_profile_location="${S8S_IPYTHON_PROFILE_LOCATION}"
  else
    ipython_profile_location="$("${CONDA_BIN_DIR}"/ipython profile locate default)"
  fi
  echo "c.InteractiveShellApp.extensions.append('google.cloud.bigquery')" >>"${ipython_profile_location}/ipython_config.py"

  # Load sparksql-magic when ipython starts for serverless
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
    echo "c.InteractiveShellApp.extensions.append('sparksql_magic')" >>"${ipython_profile_location}/ipython_config.py"
  fi
}

function enable_jupyter_extensions() {
  if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]] &&
      [[ "${DATAPROC_IMAGE_VERSION}" =~ [12]\.2 ]]; then
    local -r nbextension_subcomand='nbclassic-extension'
    local -r serverextension_subcomand='nbclassic-serverextension'
  else
    local -r nbextension_subcomand='nbextension'
    local -r serverextension_subcomand='serverextension'
  fi

  # widgetsnbextension
  "${CONDA_BIN_DIR}/jupyter" "${nbextension_subcomand}" enable widgetsnbextension --py --system

  # nbdime
  "${CONDA_BIN_DIR}/jupyter" "${nbextension_subcomand}" install nbdime --py --system --symlink
  "${CONDA_BIN_DIR}/jupyter" "${nbextension_subcomand}" enable nbdime --py --system
  "${CONDA_BIN_DIR}/jupyter" "${serverextension_subcomand}" enable nbdime --py --system

  # jupyter_http_over_ws
  if [[ "${DATAPROC_IMAGE_TYPE}" == "standard" ]] ||
      [[ "${DATAPROC_IMAGE_VERSION}" =~ [12]\.[10] ]]; then
    "${CONDA_BIN_DIR}/jupyter" "${serverextension_subcomand}" enable jupyter_http_over_ws --py --system
  fi
}

function enable_spark_monitor_for_jupyter() {
  local ipython_profile_location
  ipython_profile_location="$("${CONDA_BIN_DIR}"/ipython profile locate default)"

  # This for now will only work with Python 3 kernel. Details are at (b/134432143)
  "${CONDA_BIN_DIR}"/jupyter nbextension install sparkmonitor --py --system --symlink
  "${CONDA_BIN_DIR}"/jupyter nbextension enable sparkmonitor --py --system
  "${CONDA_BIN_DIR}"/jupyter serverextension enable --py --system sparkmonitor
  echo "c.InteractiveShellApp.extensions.append('sparkmonitor.kernelextension')" >>"${ipython_profile_location}/ipython_kernel_config.py"
}
