source "${OS_BDUTIL_DIR}/components/shared/kerberos.sh"

readonly HANDS_OFF_PASSWORD="/tmp/cluster/kerberos.password"

function read_hands_off_kerberos_password() {
  # $1 is the local keyfile to read
  echo "$(<"$1")"
}

function decrypt_with_kms_key() {
  local -r encrypted_file=$1
  local -r kms_key_uri=$2
  retry_quiet \
    decrypt_file_with_kms_key "${encrypted_file}" "${kms_key_uri}"
}

function get_kerberos_root_password_from_gcs() {
  local -r kms_key_uri=$1
  local root_password_uri
  root_password_uri=$(get_dataproc_property kerberos.root.principal.password.uri)
  if [[ -z "${root_password_uri}" ]]; then
    log_and_fail "kerberos" "Kerberos component is enabled but failed to read root principal password URI \
  from Dataproc properties. Set it through 'dataproc:kerberos.root.principal.password.uri'." "${EXIT_CODE_CLIENT_ERROR}"
  fi

  local root_password
  root_password=$(decrypt_with_kms_key "${root_password_uri}" "${kms_key_uri}")
  status=$?
  if [[ $status -ne 0 ]]; then
    echo "kerberos failed to get encrypted file from Google Cloud Storage and/or failed to decrypt using \
    the KMS key. Please make sure the KMS key ${kms_key_uri} exists, the VM service account has \
    'storage.objects.get' permission to ${root_password_uri}, and \
    'cloudkms.cryptoKeyVersions.useToDecrypt' permission to ${kms_key_uri}."
    exit "${EXIT_CODE_CLIENT_ERROR}"
  fi

  if [[ -z "${root_password}" ]]; then
    log_and_fail "kerberos" "Root principal password cannot be empty!" "${EXIT_CODE_CLIENT_ERROR}"
  fi

  echo "${root_password}"
}

function get_kerberos_root_password() {
  # Try to use the handsoff kerberos key first.
  local kerberos_password
  if [[ -f HANDS_OFF_PASSWORD ]]; then
    kerberos_password="$(read_hands_off_kerberos_password ${HANDS_OFF_PASSWORD})"
  else
    local -r kerberos_kms_key_uri="$(get_dataproc_property kerberos.kms.key.uri)"
    kerberos_password=$(get_kerberos_root_password_from_gcs "${kerberos_kms_key_uri}")
  fi
  echo "${kerberos_password}"
}
