source "${BDUTIL_DIR}/bdutil_versions.sh"

# It must meet the strength requirements.
# https://dev.mysql.com/doc/refman/8.0/en/validate-password-options-variables.html
MYSQL_DEFAULT_ROOT_PASSWORD='Root+password1'

# TODO pin MySQL to 5.7 in 2.1-rocky8 until the compatibility
# issue is resolved.
if is_version_at_least "${DATAPROC_IMAGE_VERSION}" '2.2'; then
  MYSQL_VERSION=8.0
  MYSQL_EL_VERSION=8
elif is_version_at_least "${DATAPROC_IMAGE_VERSION}" '2.1' && ! is_rocky; then
  MYSQL_VERSION=8.0
  MYSQL_EL_VERSION=8
else
  MYSQL_VERSION=5.7
  MYSQL_EL_VERSION=7
  #Locking mysql version to avoid upgrade to mysql version with Openssl 3.0
  # TODO
  MYSQL_SUBMINOR_VERSION=42
fi

## do not use set -x for this function. It is a direct output into the caller.
function read_mysql_password() {
  set +x
  local db_mysqlroot_password
  db_mysqlroot_password="$(grep 'password=' /etc/mysql/my.cnf | sed 's/^.*=//')"
  echo "${db_mysqlroot_password}"
  set -x
}


function change_file_permission() {
   echo "Changing file permissions on my.cnf"
   chmod 600 /etc/mysql/my.cnf
}


function reset_mysql_password() {
  set +x
  echo "Connecting to mysql to reset password"

  NEW_MYSQL_PASSWD="$(random_password)"

  # Wildcard % allows connections from all hosts.
  # generate random password using dev/random in hex code and strip all spaces

  mysql -u root "-p${MYSQL_DEFAULT_ROOT_PASSWORD}" -e " \
      ALTER USER 'root'@'localhost' IDENTIFIED BY '${NEW_MYSQL_PASSWD}'; \
      FLUSH PRIVILEGES;"

  echo "Mysql password reset."

  echo "
[client]
user=root
password=${NEW_MYSQL_PASSWD}" >> /etc/mysql/my.cnf

  echo "Stored mysql information in a safe place"
  set -x
}

function configure_mysql_driver_link() {
  echo "Creating MySQL driver link"
  ln -s /usr/share/java/mysql-connector-j-*.jar /usr/share/java/mysql-connector-j.jar
}

function configure_mysql_symlink() {
  echo "Creating MySQL Connector symbolic link"
  ln -s /usr/share/java/mysql-connector-j.jar /usr/share/java/mysql.jar
  # Ranger requires MySQL connector at /usr/share/java/mysql-connector-java.jar
  if ! is_rocky; then
   ln -s /usr/share/java/mysql-connector-j.jar /usr/share/java/mysql-connector-java.jar
  fi
}
