export SPARK_HOME='/usr/lib/spark'
export SPARK_JARS_DIR="${SPARK_HOME}/jars"
if [[ "${DATAPROC_IMAGE_TYPE}" == 'standard' && "${DATAPROC_IMAGE_VERSION}" =~ ^2\.[01]$ ]] ||
    [[ "${DATAPROC_IMAGE_TYPE}" == 'serverless-spark' && "${DATAPROC_IMAGE_VERSION}" =~ ^1\.1|2\.0$ ]]; then
  export SPARK_CONNECTOR_DIR="${SPARK_HOME}/external"
else
  export SPARK_CONNECTOR_DIR="${SPARK_HOME}/connector"
fi
export SPARK_CONF_DIR='/etc/spark/conf'
export SPARK_AUTH_SECRET_FILE='/tmp/cluster/spark.auth.secret'
export SPARK_DEFAULT_IMAGE_FILE='/tmp/spark-default-image.tar'

if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
  export SPARK_UI_PORT=4040
  export SPARK_MASTER_PORT=7077
  export SPARK_MASTER_WEBUI_PORT=18081
  export SPARK_WORKER_PORT=7078
  export SPARK_WORKER_WEBUI_PORT=18082

  export SPARK_UID=1099
  export SPARK_GID=1099
  export DATA_DISK_MOUNT_POINT='/var/dataproc'
  export SPARK_DATA_DIR="${DATA_DISK_MOUNT_POINT}/tmp/spark"
  export SPARK_LOG_DIR="${DATA_DISK_MOUNT_POINT}/log/spark"
else
  export SPARK_DATA_DIR='/hadoop/spark'
  export SPARK_LOG_DIR='/var/log/spark'
fi

export SPARK_TMP_DIR="${SPARK_DATA_DIR}/tmp"
export SPARK_WORK_DIR="${SPARK_DATA_DIR}/work"

export SPARK_CONNECT_PORT='15001'
export SPARK_CONNECT_PROXY_PORT='8443'
export SPARK_CONNECT_SYSTEMD_UNIT_PATH="/usr/lib/systemd/system/spark-connect.service"
export SPARK_CONNECT_PROXY_SYSTEMD_UNIT_PATH="/usr/lib/systemd/system/spark-connect-proxy.service"

function start_spark_history_server() {
  enable_service spark-history-server
  retry_constant systemctl start spark-history-server
}

function pull_image_using_containerd() {
  local -r image="$1"
  if [[ "${image}" == "${SPARK_CONTAINER_IMAGE_DEFAULT}" ]]; then
    echo "Using the default container image"
  elif check_image_pull_start; then
    echo "Image ${image} prefetch was started during initialization."
    local -r image_pull_output="$(get_image_pull_output)" # wait if needed
    echo "${image_pull_output}"
    if ! check_image_pull_successful "${image}"; then
      echo "Image ${image} prefetch was unsuccessful." # exit if there was error
      exit 1
    fi
  else
    echo "Pulling image ${image}"
    local old_x_setting
    old_x_setting=${-//[^x]/}
    set +x

    local token
    token=$(get_auth_token)
    retry_quiet crictl pull --creds="oauth2accesstoken:${token}" "${image}"

    if [[ -n "$old_x_setting" ]]; then
      set -x
    fi
  fi
}

function get_spark_container_memory() {
  local role
  role=$(get_metadata_role)
  local memory_property
  local memory_overhead_property
  if [[ "${role}" == 'Master' ]]; then
    memory_property='spark.driver.memory'
    memory_overhead_property='spark.driver.memoryOverhead'
  else
    memory_property='spark.executor.memory'
    memory_overhead_property='spark.executor.memoryOverhead'
  fi

  local memory
  memory=$(get_java_property \
    "${SPARK_CONF_DIR}/spark-defaults.conf" "${memory_property}")
  local memory_bytes
  memory_bytes=$(get_size_in_bytes "${memory}")

  local memory_overhead
  memory_overhead=$(get_java_property \
    "${SPARK_CONF_DIR}/spark-defaults.conf" "${memory_overhead_property}")
  local memory_overhead_bytes
  memory_overhead_bytes=$(get_size_in_bytes "${memory_overhead}")

  echo "$((memory_bytes + memory_overhead_bytes))"
}

function should_start_spark_connect() {
  local role
  role=$(get_metadata_role)
  local spark_connect_enabled
  spark_connect_enabled=$(get_java_property \
    "${CLUSTER_PROPERTIES_DIR}/dataproc.properties" internal.s8s.spark-connect.enabled)
  [[ "${role}" == "Master" ]] && [[ "${spark_connect_enabled}" == "true" ]]
}
