
readonly ZOOKEEPER_CONF_DIR="/etc/zookeeper/conf"
readonly ZOOKEEPER_CONFIG_FILE="/etc/zookeeper/conf/zoo.cfg"
readonly ZOOKEEPER_LOGBACK_FILE="/etc/zookeeper/conf/logback.xml"
readonly ZOOKEEPER_LOG_DIR="/var/log/zookeeper"
readonly ZOOKEEPER_LOG_FILE="${ZOOKEEPER_LOG_DIR}/zookeeper.log"

# Returns list of zookeeper servers configured in the zoo.cfg file.
function get_zookeeper_list() {
  local zookeeper_client_port
  zookeeper_client_port=$(grep 'clientPort' "${ZOOKEEPER_CONFIG_FILE}" |
    tail -n 1 |
    cut -d '=' -f 2)
  zookeeper_list=$(grep '^server.' "${ZOOKEEPER_CONFIG_FILE}" |
      tac |
      sort -u -t '=' -k1,1 |
      cut -d '=' -f 2 |
      cut -d ':' -f 1 |
      sed "s/$/:${zookeeper_client_port}/" |
      xargs echo |
      sed "s/ /,/g")
  echo "${zookeeper_list}"
}
# Returns list of zookeeper servers configured in the zoo.cfg file which will be
# part of `hbase.zookeeper.quorum` parameter.
# As per standards this should only have a list of master server names
# http://svn.apache.org/repos/asf/hbase/hbase.apache.org/trunk/0.94/zookeeper.html
function get_zookeeper_server_list_for_zk_quorum() {
  local zookeeper_server_names
  zookeeper_server_names=$(grep '^server.' "${ZOOKEEPER_CONFIG_FILE}" |
    tac |
    sort -u -t '=' -k1,1 |
    cut -d '=' -f 2 |
    cut -d ':' -f 1 |
    xargs echo |
    sed "s/ /,/g")
  echo "${zookeeper_server_names}"
}
function get_zookeeper_port_for_zk_quorum() {
  local zookeeper_port
  zookeeper_port=$(grep 'clientPort' "${ZOOKEEPER_CONFIG_FILE}" |
    tail -n 1 |
    cut -d '=' -f 2)
  echo "${zookeeper_port}"
}
# Waits for zookeeper to be ready.
function wait_for_zookeeper() {
  local zookeeper_list
  zookeeper_list=$(get_zookeeper_list)
  local -r zookeeper_address="${zookeeper_list%%,*}"
  retry_constant \
    /usr/lib/zookeeper/bin/zkCli.sh -server "${zookeeper_address}" ls /
}

function add_logdir_property() {
  cat >>"/usr/lib/zookeeper/bin/zkEnv.sh" <<EOF

ZOO_LOG_DIR="${ZOOKEEPER_LOG_DIR}"
EOF
}

function insert_elem_attr() {
  local file_name=$1
  local name_value=$2
  sed -i '/^<\/configuration>/i \ '"${name_value}" "${file_name}"
}

function add_console_warn_property() {
  insert_elem_attr "${ZOOKEEPER_LOGBACK_FILE}" ""
  insert_elem_attr "${ZOOKEEPER_LOGBACK_FILE}" " <root level=\"WARN\">"
  insert_elem_attr "${ZOOKEEPER_LOGBACK_FILE}" "   <appender-ref ref=\"CONSOLE\" />"
  insert_elem_attr "${ZOOKEEPER_LOGBACK_FILE}" " </root>"
}
