# Copyright 2015 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Configures Bigtable HBase Java Client for use with ATSv2.

function configure_bigtable_hbase_client() {
  local -r bigtable_project="$1"
  local -r bigtable_instance_id="$2"

  mkdir -p "${BIGTABLE_HBASE_CONF_DIR}"
  local -r hbase_config="${BIGTABLE_HBASE_CONF_DIR}/hbase-site.xml"
  cat >"${hbase_config}" <<EOF
<?xml version="1.0"?>
<?xml-stylesheet type="text/xsl" href="configuration.xsl"?>
<configuration>
  <property><name>google.bigtable.project.id</name><value>${bigtable_project}</value></property>
  <property><name>google.bigtable.instance.id</name><value>${bigtable_instance_id}</value></property>
  <property>
    <name>hbase.client.connection.impl</name>
    <value>${BIGTABLE_HBASE_CLIENT_CONNECTION_IMPL}</value>
  </property>
  <property>
    <name>hbase.client.registry.impl</name>
    <value>org.apache.hadoop.hbase.client.BigtableAsyncRegistry</value>
  </property>
  <property>
    <name>hbase.client.async.connection.impl</name>
    <value>org.apache.hadoop.hbase.client.BigtableAsyncConnection</value>
  </property>
  <!-- Spark-HBase-connector uses namespaces, which bigtable doesn't support. This has the
  Bigtable client log warns rather than throw -->
  <property><name>google.bigtable.namespace.warnings</name><value>true</value></property>
</configuration>
EOF
}
