#!/usr/bin/env bash

# Configure default metrics :
# Moving the collectd plugin configuration files for default spark metrics
# from bdutil/conf to the collectd path /opt/stackdriver/collectd/etc/collect.d/

set -e
set -u
loginfo 'Running configure_default_metrics.sh'
source "${BDUTIL_DIR}/bdutil_metadata.sh"
source "${BDUTIL_DIR}/bdutil_properties.sh"

# Update collectd config files for default metrics and update the default collectd.conf file
function update_default_collectd_config_files() {
  local -r collectd_plugin_dir="/opt/stackdriver/collectd/etc/collectd.d/"

  # Default collectd.conf file at /etc/stackdriver/collectd.conf contains plugins
  # (like cpu, agent, disk, interface, load, memory, pagefile, processes, swap)
  # that are enabled by default.
  # We ignore these plugins (except agent) when monitoring_agent_defaults is not
  # enabled. By replacing the collectd.conf with the minimal configuration at
  # collectd_without_monitoring_agent_defaults.conf. When monitoring_agent_defaults
  # is enabled as a metric source, we replace the collectd.conf with a
  # config file that is compatible with the OSS metric configs
  if ! is_metric_source_enabled "${MONITORING_AGENT_DEFAULTS_SOURCE}"; then
    sed -i "/stackdriver_agent/d" "${BDUTIL_DIR}/conf/collectd_without_monitoring_agent_defaults.conf"
    cp "${BDUTIL_DIR}/conf/collectd_without_monitoring_agent_defaults.conf" "/etc/stackdriver/collectd.conf"

    cp "${BDUTIL_DIR}/conf/${PROCESSES_DEFAULT_METRICS_CONF_FILE_NAME}" "${collectd_plugin_dir}/${PROCESSES_DEFAULT_METRICS_CONF_FILE_NAME}"
  else
    cp "${BDUTIL_DIR}/conf/collectd_default_filtered_write.conf" "/etc/stackdriver/collectd.conf"
  fi

  # Copy default collectd files when default metrics are enabled
  cp "${BDUTIL_DIR}/conf/${SPARK_DEFAULT_METRICS_CONF_FILE_NAME}" "${collectd_plugin_dir}/${SPARK_DEFAULT_METRICS_CONF_FILE_NAME}"

}

update_default_collectd_config_files
