#!/bin/bash

# Do any necessary dynamic fluent-bit configuration

set -e
set -u
loginfo "Running configure_fluentbit.sh"

UCP_LOGGING_AGENT_PATH="/etc/ucp/logging"
FLUENTBIT_CONF_DIR="${UCP_LOGGING_AGENT_PATH}/configs"

function setup_fluentbit_confs() {
  mkdir -p "${FLUENTBIT_CONF_DIR}"
  cp -r "${BDUTIL_DIR}"/fluentbit/* "${FLUENTBIT_CONF_DIR}"
}

function substitute_conf_placeholders() {
  local -r job_driver_logging_enabled=$(get_dataproc_property \
    dataproc.logging.stackdriver.job.driver.enable)

  local include_job_driver_logs=""
  if [[ "${job_driver_logging_enabled}" == "true" ]]; then
    include_job_driver_logs="@INCLUDE job-driverlogs-fluentbit.conf"
  fi

  # Substitute the @INCLUDE for job driver logs
  sed -i -e "s#INCLUDE_JOB_DRIVER_LOGS_PLACEHOLDER#${include_job_driver_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/fluentbit.conf

  local -r container_logging_enabled=$(get_dataproc_property \
    dataproc.logging.stackdriver.job.yarn.container.enable)

  local include_yarn_user_or_jobcontainer_logs="@INCLUDE yarn-userlogs-fluentbit.conf"
  if [[ "${container_logging_enabled}" == "true" ]]; then
    include_yarn_user_or_jobcontainer_logs="@INCLUDE job-yarn-containerlogs-fluentbit.conf"
  fi

  # Substitute the @INCLUDE for yarn userlogs or job container logs
  sed -i -e "s#INCLUDE_YARN_USER_OR_JOBCONTAINER_LOGS_PLACEHOLDER#${include_yarn_user_or_jobcontainer_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/fluentbit.conf

  local include_dpms_proxy_logs=""
  if is_component_selected "dpms-proxy"; then
    include_dpms_proxy_logs="@INCLUDE dpms_proxy_fluentbit.conf"
  fi

  # Substitute the @INCLUDE for dpms-proxy component logs
  sed -i -e "s#INCLUDE_DPMS_PROXY_LOGS_PLACEHOLDER#${include_dpms_proxy_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/fluentbit.conf

  # Configure optional logging
  local -r is_caching_enabled=$(get_dataproc_property_or_default dataproc.cluster.caching.enabled "false")

  local include_cluster_caching_logs=""
  if [[ "${is_caching_enabled}" == "true" ]]; then
    include_cluster_caching_logs="@INCLUDE optional_logging/dataproc-cluster-caching-fluentbit.conf"
  fi

  # Substitute the @INCLUDE for cluster caching logs
  sed -i -e "s#INCLUDE_CLUSTER_CACHING_LOGS_PLACEHOLDER#${include_cluster_caching_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/fluentbit.conf

  local -r worker_earlyoom_enabled=$(get_dataproc_property_or_default \
    internal.node.main.memory-protection-worker.enabled "false")

  local include_earlyoom_logs=""
  if [[ "${ROLE}" == "Worker" && "${worker_earlyoom_enabled}" == "true" ]]; then
    include_earlyoom_logs="@INCLUDE optional_logging/dataproc-earlyoom-fluentbit.conf"
  fi

  # Substitute the @INCLUDE for earlyoom logs
  sed -i -e "s#INCLUDE_EARLYOOM_LOGS_PLACEHOLDER#${include_earlyoom_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/fluentbit.conf
}

function substitute_optional_hadoop_dirs() {
  local optional_components_logs=""
  if is_component_selected "presto"; then
    optional_components_logs+="/var/log/presto/*.log,"
  fi
  if is_component_selected "flink"; then
    optional_components_logs+="/var/log/flink/*.log,/var/log/flink-cli/*.log,"
  fi
  if is_component_selected "druid"; then
    optional_components_logs+="/var/log/druid/*.log,"
  fi
  if is_component_selected "hbase"; then
    optional_components_logs+="/var/log/hbase/*.log,"
  fi
  if is_component_selected "ranger"; then
    optional_components_logs+="/var/log/ranger/admin/ranger-admin-*.log,"
  fi

  # Include additional directories only if respective component was enabled
  # Otherwise, fluentbit cannot access these directories because they wouldn't exist, leading to
  # read errors in syslog
  # For same reason, always pre-create the directories associated with Dataproc jobs, cloud-sql-proxy
  # and YARN containers
  sed -i -e "s#OPTIONAL_COMPONENTS_PLACEHOLDER#${optional_components_logs}#" \
    "${FLUENTBIT_CONF_DIR}"/hadoop_fluentbit.conf
  mkdir -p "/var/log/google-dataproc-job"
  mkdir -p "/var/log/cloud-sql-proxy"
  mkdir -p "/var/log/hadoop-yarn"
  chown yarn:hadoop -R "/var/log/hadoop-yarn"
  mkdir -p "/var/log/hadoop-yarn/userlogs"
  chown yarn:yarn -R "/var/log/hadoop-yarn/userlogs"
}

setup_fluentbit_confs
substitute_conf_placeholders
substitute_optional_hadoop_dirs
