#!/usr/bin/env bash

# Do any necessary dynamic fluentd configuration

set -eu

loginfo 'Running configure_fluentd.sh'

source "${BDUTIL_DIR}/bdutil_misc.sh"
source "${BDUTIL_DIR}/components/shared/earlyoom.sh"

FLUENTD_BASE_DIR='/etc/google-fluentd'
FLUENTD_CONF_DIR="${FLUENTD_BASE_DIR}/config.d"
FLUENTD_PLUGIN_DIR="${FLUENTD_BASE_DIR}/plugin"

if is_containerised_legacy_agents_supported; then
  mkdir -p "${FLUENTD_BASE_DIR}"
  cp "${BDUTIL_DIR}/fluentd/base_fluentd.conf" "${FLUENTD_BASE_DIR}/google-fluentd.conf"
fi

mkdir -p "${FLUENTD_CONF_DIR}"
mkdir -p "${FLUENTD_PLUGIN_DIR}"

# Note we use cp here instead of mv for idempotency and to ensure that if
# customers customize the fluentd configuration directory, we want to try to
# preserve that config.

# Disable writing agent-internal metrics (b/181226420, b/266687319).
# TODO: Re-enable these metrics.
sed -i -e 's/enable_monitoring true/enable_monitoring false/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
if [[ "${DATAPROC_IMAGE_TYPE}" == "serverless-spark" ]]; then
  # Use job plugin artifacts here and just modify the plugin for batch
  cp -r "${BDUTIL_DIR}"/fluentd/job_logging/plugin/* "${FLUENTD_PLUGIN_DIR}"
  # For Batch, we need a forked plugin which allows Dataproc Batch logging
  cp -r "${BDUTIL_DIR}"/fluentd/serverless_logging/plugin/* "${FLUENTD_PLUGIN_DIR}"
  # For Batch, we only need spark, dataproc-agent and dataproc-startup logs
  cp -r "${BDUTIL_DIR}"/fluentd/serverless_logging/config.d/* "${FLUENTD_CONF_DIR}"

  # Wait 1s before the first retry, then double the wait interval on each
  # following retry (2s, 4s, 8s, 16s), up to 5 retries. If retries are
  # exhausted, the given chunk will be discarded.
  sed -i -e 's/retry_wait \(.*\)/retry_wait 1/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  sed -i -e 's/retry_limit \(.*\)/retry_limit 5/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  sed -i -e 's/max_retry_wait \(.*\)/max_retry_wait 30/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  sed -i -e 's/disable_retry_limit \(.*\)/disable_retry_limit false/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  # Reduce buffer size and enable compression
  sed -i -e 's/buffer_chunk_limit \(.*\)/buffer_chunk_limit 64KB/' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  sed -i -e '/use_grpc \(.*\)/a grpc_compression_algorithm gzip' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
  sed -i -e '/use_grpc \(.*\)/a flush_at_shutdown true' "${FLUENTD_BASE_DIR}/google-fluentd.conf"
else
  cp -r "${BDUTIL_DIR}"/fluentd/config.d/* "${FLUENTD_CONF_DIR}"

  # Use our own, forked version of the plugin until we upstream the changes to
  # allow Dataproc Job logging. b/128346997
  cp -r "${BDUTIL_DIR}"/fluentd/job_logging/plugin/* "${FLUENTD_PLUGIN_DIR}"

  JOB_DRIVER_LOGGING_ENABLED=$(get_dataproc_property \
    dataproc.logging.stackdriver.job.driver.enable)

  if [[ "${JOB_DRIVER_LOGGING_ENABLED}" == 'true' ]]; then
    # Copy the configurations to enable the Job driver logs to Stackriver.
    cp -r "${BDUTIL_DIR}"/fluentd/job_logging/config.d/* "${FLUENTD_CONF_DIR}"
  fi

  CONTAINER_LOGGING_ENABLED=$(get_dataproc_property \
    dataproc.logging.stackdriver.job.yarn.container.enable)

  if [[ "${CONTAINER_LOGGING_ENABLED}" == 'true' ]]; then
    cp -r "${BDUTIL_DIR}"/fluentd/container_logging/plugin/*.rb "${FLUENTD_PLUGIN_DIR}"
    cp -r "${BDUTIL_DIR}"/fluentd/container_logging/config.d/* "${FLUENTD_CONF_DIR}"
  fi

  # Configure optional logging
  is_caching_enabled=$(get_dataproc_property_or_default dataproc.cluster.caching.enabled "false")
  if [[ "${is_caching_enabled}" == "true" ]]; then
    cp -r "${BDUTIL_DIR}"/fluentd/optional_logging/config.d/dataproc-cluster-caching-*.conf "${FLUENTD_CONF_DIR}"
  fi

  # Configure logging for EarlyOOM
  if is_earlyoom_enabled; then
    cp "${BDUTIL_DIR}"/fluentd/optional_logging/config.d/dataproc-earlyoom.conf "${FLUENTD_CONF_DIR}"
  fi
fi
