# Copyright 2019 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require_relative 'dataproc_yarn_job_id_resolver'
require_relative 'gce_metadata_reader'
require_relative 'yarn_properties_provider'
require_relative 'yarn_rest_client'


module DataprocJobIdResolver

  # A provider to get an instance of a YarnBasedJobIdResolver
  #
  #  This provider exists to allow injecting stubs into the FilterAppIdToJobId
  #  plugin because Fluentd plugins are not allowed initializers that take
  #  arguments (the normal, DI path for stub injection).
  module Provider

    KERBERIZED_DATAPROC_CA_FILE = '/etc/hadoop/conf/ssl/truststore.pem'

    def self.default
      rm_hosts = [read_required_attribute('dataproc-master')] +
          read_required_attribute('dataproc-master-additional').split(',')
      use_https = Yarn::PropertiesProvider.use_https
      yarn_rest_client = nil
      if use_https
        # We need the fully qualified domain name to work with the ca file.
        domain = `dnsdomainname`.strip
        fqdn_rm_hosts = rm_hosts.map {|rm_host| rm_host + '.' + domain }
        https_port = Yarn::PropertiesProvider.rm_https_port
        yarn_rest_client = Yarn::RestClient.new(
          fqdn_rm_hosts, https_port, use_https, KERBERIZED_DATAPROC_CA_FILE)
      else
        http_port = Yarn::PropertiesProvider.rm_http_port
        yarn_rest_client = Yarn::RestClient.new(
          rm_hosts, http_port, use_https, nil)
      end
      DataprocJobIdResolver::YarnBasedJobIdResolver.new(yarn_rest_client)
    end

    def self.read_required_attribute(key)
      value = GceMetadata::AttributeReader.read(key)
      raise "No value for required GCE Metadata Attribute: #{key}." unless value
      value
    end
  end
end
