#!/usr/bin/env rspec

require 'json'
require 'rspec'
require_relative 'dataproc_yarn_job_id_resolver'
require_relative 'yarn_rest_client'


RSpec.describe DataprocJobIdResolver::YarnBasedJobIdResolver do

  before(:example) do
    @mock_yarn_client = instance_double('YarnClient')
    @resolver = DataprocJobIdResolver::YarnBasedJobIdResolver.
        new(@mock_yarn_client)
  end

  def setup_mock_from_json_file(path, app_id)
    app_json_obj = JSON.parse(open(path, &:read))
    allow(@mock_yarn_client).to receive(:get_app).with(app_id).
        and_return(app_json_obj)
  end

  it 'correctly extracts IDs from application json objects' do
    app_id = 'application_1548790533163_0001'
    app_job_id = 'a3d005eb6b8c47ae9e89e80ec8151c3f'
    app_job_uuid = 'd9cd2da3-f83c-3e46-985a-a5548e6697d8'
    setup_mock_from_json_file('data/yarn_app_normal.json', app_id)
    resolved = @resolver.resolve(app_id)
    expect(resolved).to_not be_nil
    expect(resolved.job_id).to eq(app_job_id)
    expect(resolved.job_uuid).to eq(app_job_uuid)
  end

  it 'returns nil when yarn_client returns nil' do
    app_id = 'application_123_001'
    allow(@mock_yarn_client).to receive(:get_app).with(app_id).and_return(nil)
    expect(@resolver.resolve(app_id)).to be_nil
  end

  it 'returns nil when there is no uuid tag' do
    app_id = 'application_1548790533163_0001'
    setup_mock_from_json_file('data/yarn_app_no_uuid_tag.json', app_id)
    expect(@resolver.resolve(app_id)).to be_nil
  end

  it 'returns nil when there is no id tag' do
    app_id = 'application_1548790533163_0001'
    setup_mock_from_json_file('data/yarn_app_no_id_tag.json', app_id)
    expect(@resolver.resolve(app_id)).to be_nil
  end

  it 'returns nil when there is no application tags' do
    app_id = 'application_1548790533163_0001'
    setup_mock_from_json_file('data/yarn_app_no_app_tags_field.json', app_id)
    expect(@resolver.resolve(app_id)).to be_nil
  end
end
