#!/usr/bin/env rspec

require 'rspec'
require 'webmock/rspec'
require_relative 'gce_metadata_reader'


RSpec.describe GceMetadata::AttributeReader do

  before(:example) do
    WebMock.disable_net_connect!
  end

  it 'should return nil when response code != 200' do
    stub_request(:get,
        ('http://metadata.google.internal/computeMetadata/v1/instance/' +
         'attributes/dataproc-master')).
        to_return(body: '<!DOCTYPE html>blahblahblah...', status: 404)
    expect(GceMetadata::AttributeReader.read('dataproc-master')).to be_nil
  end

  it 'should return the response body when response code == 200' do
    stub_request(:get,
        ('http://metadata.google.internal:80/computeMetadata/v1/instance/' +
         'attributes/dataproc-master')).
        with(headers: { 'Metadata-Flavor' => 'Google' }).
        to_return(body: 'my-cluster-m', status: 200)
    expect(GceMetadata::AttributeReader.read('dataproc-master')).
        to eq('my-cluster-m')
  end
end
