#!/usr/bin/env rspec

require 'rspec'
require_relative 'yarn_properties_provider'


RSpec.describe Yarn::PropertiesProvider do
  it 'returns ports from custom webapp address properties' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.resourcemanager.webapp.address').
        and_return('my-cluster-m:1337').once
    expect(Yarn::PropertiesProvider.rm_http_port).
        to eq(1337)
  end

  it 'returns 8088 when unable to find property' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.resourcemanager.webapp.address').
        and_return('').once
    expect(Yarn::PropertiesProvider.rm_http_port).
        to eq(8088)
  end

  it 'returns 8088 when unable to find hdfs command' do
    expect(Yarn::PropertiesProvider.rm_http_port).
        to eq(8088)
  end

  it 'returns ports from custom webapp https address properties' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.resourcemanager.webapp.https.address').
        and_return('my-cluster-m:1337').once
    expect(Yarn::PropertiesProvider.rm_https_port).
        to eq(1337)
  end

  it 'returns 8090 when unable to find https property' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.resourcemanager.webapp.https.address').
        and_return('').once
    expect(Yarn::PropertiesProvider.rm_https_port).
        to eq(8090)
  end

  it 'returns 8090 for https when unable to find hdfs command' do
    expect(Yarn::PropertiesProvider.rm_https_port).
        to eq(8090)
  end

  it 'returns true when http policy is set to HTTPS_ONLY' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.http.policy').
        and_return('HTTPS_ONLY').once
    expect(Yarn::PropertiesProvider.use_https).to be true
  end

  it 'returns false when http policy is set to HTTP_ONLY' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.http.policy').
        and_return('HTTP_ONLY').once
    expect(Yarn::PropertiesProvider.use_https).to be false
  end

  it 'returns false when http policy is unset' do
    expect(Yarn::PropertiesProvider).to receive(:`).
        with('hdfs getconf -confKey yarn.http.policy').
        and_return('').once
    expect(Yarn::PropertiesProvider.use_https).to be false
  end
end
