# Copyright 2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
set -euxo pipefail

loginfo 'Running generate_collectd_plugin.sh'

VIRTUALENV_PATH="${DATAPROC_DIR}/system/virtualenv"

function install_dependencies_for_monitoring_plugin_generator() {
  local pip_command
  if command -v pip >/dev/null; then
    pip_command="pip"
  elif command -v pip3 >/dev/null; then
    pip_command="pip3"
  else
    loginfo "pip command is not installed"
    exit 1
  fi

  # Pinning virtualenv version for debian images b/193590128
  if is_debian10; then
    "${pip_command}" install "virtualenv==20.4.7"
  else
    "${pip_command}" install virtualenv
  fi

  # create a separated project environment for Stackdriver collectd plugins.
  mkdir -p "${VIRTUALENV_PATH}"
  virtualenv "${VIRTUALENV_PATH}"

  # Activate the virtualenv
  set +u
  # shellcheck source=/dev/null
  source "${VIRTUALENV_PATH}/bin/activate"
  set -u

  # Install jinja and pyyaml inside the virtualenv
  "${pip_command}" install Jinja2 pyyaml

  # Deactivate the virtualenv
  deactivate
}

function generate_collectd_default_configuration_files() {
  (
      # Quit the bash strict mode, because virtualenv script might cause unbound
      # variable error.
      set +u

      # Activate the virtualenv
      source "${DATAPROC_DIR}/system/virtualenv/bin/activate"
      local -r collectd_plugin_gen_dir="${BDUTIL_DIR}/monitoring_plugin_generator"
      # Run jinja to generate the collectd plugin and replace the default one.
      # File name should be the same as the default file name for service for the override to work correctly.
      # shellcheck disable=SC2046 "Need unquoted expansion to pass kwargs to python"
      python "${collectd_plugin_gen_dir}/dataproc_monitoring_plugin_generator.py" \
          --metrics_file "${collectd_plugin_gen_dir}/dataproc-default-metrics.txt" \
          --plugin_generator_config_dir "${collectd_plugin_gen_dir}" \
          --output_dir "${BDUTIL_DIR}/conf" \
          --templates_dir "${collectd_plugin_gen_dir}" \
          --output_file_name_kwargs $(get_metric_source_to_file_name_kwargs) \
          --mode "default"
      deactivate
    )
}
install_dependencies_for_monitoring_plugin_generator
generate_collectd_default_configuration_files
