# Copyright 2018 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -euxo pipefail

# This script contains utility functions that install Conscrypt and generate
# related config templates java.security.default and java.security.conscrypt
# under /usr/local/share/google/dataproc. The config templates can be applied
# optionally during cluster initialization.

DATAPROC_DIR=${DATAPROC_DIR:-/usr/local/share/google/dataproc}

function get_java_security_patch() {
  local patch_type="$1"
  case "${patch_type}" in
  default)
    get_default_java_security_patch
    ;;
  conscrypt)
    get_conscrypt_java_security_patch
    ;;
  *)
    echo 'Unknown java.security patch'
    exit 1
    ;;
  esac
}

function show_patch_failures() {
  local patched_file="$1"
  loginfo "Patching '${patched_file} failed. 3 way diff was:"
  sed -n '/<<<<<<</,/>>>>>>>/p' "${patched_file}" >&2
  exit 1
}

function patch_security_file() {
  pushd "${JAVA_CONFIG_DIR}"
  for patch_type in 'default' 'conscrypt'; do
    local patched_file="${DATAPROC_DIR}/java.security.${patch_type}"
    cp security/java.security "${patched_file}"
    patch --merge "${patched_file}" <(get_java_security_patch "${patch_type}") ||
      show_patch_failures "${patched_file}"
  done
  popd
}

function install_conscrypt() {
  loginfo "Installing Conscrypt"

  if is_java8; then
    source "${BDUTIL_DIR}/install_conscrypt_java8.sh"
  else
    source "${BDUTIL_DIR}/install_conscrypt_java11.sh"
  fi
  _install_conscrypt
  patch_security_file
}
