#!/bin/bash

set -eux


# Official support of google-fluentd and stackdriver-agent on ARM is not available yet.
# Its being tracked at b/175250671 from the cloud logging and monitoring team.
# However since google-fluentd and stackdriver agents are legacy, getting ARM
# binaries for these are unlikely in near future.
# So built the binary in-house and using directly for time being.

function install_logging_agent() {
  local -r google_fluentd_deb="google-fluentd_1.9.11-1_arm64.deb"
  local -r gcs_path="gs://dataproc-image-dependencies/arm64-packages/${google_fluentd_deb}"
  download_resource "${gcs_path}" "/tmp/"
  # Using os_install_packages to dynamically resolve dependencies, if any.
  os_install_packages "/tmp/${google_fluentd_deb}"
  rm -rf "/tmp/${google_fluentd_deb}"
}

function install_monitoring_agent() {
  local -r stackdriver_agent_deb="stackdriver-agent_6.3.1-1.focal_arm64.deb"
  local -r gcs_path="gs://dataproc-image-dependencies/arm64-packages/${stackdriver_agent_deb}"
  download_resource "${gcs_path}" "/tmp/"
  # Using os_install_packages to dynamically resolve dependencies, if any.
  os_install_packages "/tmp/${stackdriver_agent_deb}"
  rm -rf "/tmp/${stackdriver_agent_deb}"
}

function logging_agent_service_name() {
  echo "google-fluentd"
}

function monitoring_agent_service_name() {
  echo "stackdriver-agent"
}
