#!/bin/bash

readonly -A OS_PACKAGE_MAP=(
  ["debian"]="fluent-bit-latest.deb"
  ["rocky"]="fluent-bit-latest.rpm"
  ["ubuntu"]="fluent-bit-latest.deb"
)
UCP_LOGGING_AGENT_VERSION="1.9.5"

# TODO: Move to artifact repository maintained by UCP observability team
function install_ucp_logging_agent() {
  local path_prefix
  if is_debian11; then
    path_prefix=debian11
  elif is_debian12; then
    path_prefix=debian12
  elif is_rocky9; then
    path_prefix=rocky9
  elif is_ubuntu22; then
    path_prefix=ubuntu22
  fi
  local -r package_name=${OS_PACKAGE_MAP["$(os_id)"]}

  local -r installation_dir="${BUILD_DIR}/fluent-bit"
  mkdir -p "${installation_dir}"
  download_resource \
    "gs://dataproc-image-dependencies/ucp-agents/logging/${UCP_LOGGING_AGENT_VERSION}/${path_prefix}/${package_name}" \
    "${installation_dir}"
  os_install_packages "${installation_dir}/${package_name}"
  rm -r "${installation_dir}"
  if is_rocky9; then
    # Installing kafka-server on rocky9 upgrades fluent-bit, disallow it
    os_lock_package_version fluent-bit
  fi
}

# TODO: Manage installing these lua dependencies along with UCP logging agent
# installation above (once fluent-bit build includes lua 5.1 dependency explicitly).
# Currently, call this from build-image.sh after DATAPROC_COMMON_PACKAGES get installed
function install_lua_deps_for_fluentbit() {
  # Install the lua dependencies using luarocks package manager
  # luasocket, lunajson, luasec are required to make HTTP requests to YARN resource manager
  # in append_resource_labels.lua
  os_install_packages luarocks
  if is_rocky9; then
    # Since fluent-bit requires lua 5.1 and default version on rocky9 is lua 5.4,
    # install lua 5.1 binaries and headers separately
    local -r lua_version=5.1
    os_install_packages compat-lua
    os_install_packages compat-lua-devel

    local -r luarocks_tree="/usr/local"
    luarocks --lua-version $lua_version config "variables.LUA_INCDIR" "/usr/include/lua-${lua_version}"
    luarocks --lua-version $lua_version --tree "${luarocks_tree}" install luasocket
    luarocks --lua-version $lua_version --tree "${luarocks_tree}" install lunajson
    luarocks --lua-version $lua_version --tree "${luarocks_tree}" install luasec

    mkdir -p "${luarocks_tree}/lib/lua"
    ln -s "${luarocks_tree}/lib64/lua/${lua_version}" "${luarocks_tree}/lib/lua/${lua_version}"
  else
    luarocks install luasocket
    luarocks install lunajson
    luarocks install luasec
  fi
}

# install_logging_agent, install_monitoring_agent have logic only for UCP agents as the
# containerised agent images are pulled via docker. So, their installation happens in
# post-install/docker-ce.sh (when docker is available) instead of build-image.sh.
function install_logging_agent() {
  install_ucp_logging_agent
}

# logic for installing UCP monitoring agent is also in post-install/docker-ce.sh
function install_monitoring_agent() {
  return
}

function logging_agent_service_name() {
  if use_ucp_observability_agents; then
    echo "fluentbit-ucp"
  else
    echo "google-fluentd-docker"
  fi
}

function monitoring_agent_service_name() {
  if use_ucp_observability_agents; then
    echo "otel-metrics-agent"
  else
    echo "stackdriver-agent-docker"
  fi
}
