#!/usr/bin/env bash

set -eux

CLOUD_AGENTS_DL_URL="https://dl.google.com/cloudagents"

function install_logging_agent() {
  loginfo "Setting up Cloud Logging Agent repository"
  local -r add_repo_sh="add-logging-agent-repo.sh"
  curl -fsS --retry-connrefused --retry 10 --retry-max-time 30 \
    "${CLOUD_AGENTS_DL_URL}/${add_repo_sh}" -o "${add_repo_sh}"
  bash "${add_repo_sh}"
  # TODO: Unpin when we have alternative to Dataproc's forked
  # fluentd plugin currently incompatible with google-fluentd >= 1.10.0
  if is_rocky; then
    DATAPROC_COMMON_PACKAGES+=("google-fluentd-1.9.12-1.el8")
    os_lock_package_to_specific_version google-fluentd 1.9.12-1.el8
  else
    DATAPROC_COMMON_PACKAGES+=("google-fluentd=1.9.12-1")
  fi
}

function install_monitoring_agent() {
  loginfo "Setting up Cloud Monitoring Agent repository"
  local -r add_repo_sh="add-monitoring-agent-repo.sh"
  curl -fsS --retry-connrefused --retry 10 --retry-max-time 30 \
    "${CLOUD_AGENTS_DL_URL}/${add_repo_sh}" -o "${add_repo_sh}"
  bash "${add_repo_sh}"
  DATAPROC_COMMON_PACKAGES+=('stackdriver-agent')
}

function logging_agent_service_name() {
  echo "google-fluentd"
}

function monitoring_agent_service_name() {
  echo "stackdriver-agent"
}
