export MYSQL_SERVICE='mysql'
export MYSQL_CONFIG_DIR="/etc/mysql/conf.d"

# Need to do it before MySQL is installed.
function setup_mysql_repo() {
  retry_fibonacci apt-key adv --no-tty \
    --keyserver hkp://keyserver.ubuntu.com:80 \
    --recv-keys B7B3B788A8D3785C
  cat >/etc/apt/sources.list.d/mysql.list <<EOF
deb https://repo.mysql.com/apt/${OS_ID} ${OS_CODENAME} mysql-${MYSQL_VERSION} mysql-tools
EOF
}

function update_mysql_password() {
  debconf-set-selections <<<"mysql-community-server mysql-community-server/root-pass password ${MYSQL_DEFAULT_ROOT_PASSWORD}"
  debconf-set-selections <<<"mysql-community-server mysql-community-server/re-root-pass password ${MYSQL_DEFAULT_ROOT_PASSWORD}"
}

function install_mysql_bundle_debian10() {
  # mysql-server packages were removed from repo.mysql.com for debian 10.
  # Installing from a archive bundle downloaded
  # from https://downloads.mysql.com/archives/community/ page.
  local -r mysql_deb_bundle="mysql-server_5.7.42-1debian10_amd64.deb-bundle.tar"
  local -r gcs_path="gs://dataproc-image-dependencies/x86-packages/${mysql_deb_bundle}"
  mkdir -p /tmp/mysql-bundle
  download_resource "${gcs_path}" "/tmp/mysql-bundle"
  tar -C /tmp/mysql-bundle -xf "/tmp/mysql-bundle/${mysql_deb_bundle}"
  # Install with dependencies
  dpkg -i -R "/tmp/mysql-bundle/" || apt-get -f install -y
  rm -rf "/tmp/mysql-bundle"
}

function install_mysql_connector() {
  # mysql-connector-j package not marked as arm64 complaint in any of the
  # repos configured for mysql. In official ubuntu repo even though package
  # itself platform independent, still listed in only amd64 packages.
  # So downloaded the deb package from ubuntu repo and installing it manually.
  # This package installs mysql client jars for java clients.
  # Nothing specific to platform.
  # When this package is available officially from any of the repo, then
  # just remove this explicit installation.
  # This package has been removed entirely for debian10 and ubuntu20 from
  # repo.mysql.com.
  local -r mysql_connector_deb="mysql-connector-j_8.0.32-1ubuntu20.04_all.deb"
  local -r gcs_path="gs://dataproc-image-dependencies/arm64-packages/${mysql_connector_deb}"
  download_resource "${gcs_path}" "/tmp/"
  dpkg -i "/tmp/${mysql_connector_deb}"
  rm -rf "/tmp/${mysql_connector_deb}"
}

function add_mysql_packages() {
  DATAPROC_OPTIONAL_COMPONENTS+=(mysql)
  DATAPROC_COMMON_PACKAGES+=(mysql mysql-connector-j)
  DATAPROC_MASTER_EXCLUSIVE_SERVICES+=(mysql-server)
  PACKAGE_TO_SERVICE_NAME["mysql-server"]="${MYSQL_SERVICE}"
}

function lock_mysql_packages() {
  local -l version="${MYSQL_VERSION}.*"

  os_lock_package_to_specific_version mysql-server "${version}"
  os_lock_package_to_specific_version mysql-client "${version}"
  os_lock_package_to_specific_version mysql-community-server  "${version}"
  os_lock_package_to_specific_version mysql-community-client  "${version}"
}

# TODO: Migrate setup repo part to mysql install script
setup_mysql_repo
update_mysql_password
add_mysql_packages

lock_mysql_packages

if is_debian10; then
  install_mysql_bundle_debian10
fi

if is_debian10 || is_ubuntu20; then
  # Mysql connector is installed via deb package for ubuntu20
  # and debian 10 since these packages are removed from repo.
  install_mysql_connector
fi
