export MYSQL_SERVICE='mysqld'
export MYSQL_CONFIG_DIR="/etc/my.cnf.d"

function setup_mysql_repo() {
  # Disable the Default MySQL Module, ignore failures if not found.
  yum -y module disable mysql || true 

  cat >/etc/yum.repos.d/mysql-community.repo <<EOF
[mysql-community]
name=MySQL ${MYSQL_VERSION} Community Server
baseurl=http://repo.mysql.com/yum/mysql-${MYSQL_VERSION}-community/el/${MYSQL_EL_VERSION}/x86_64/
enabled=1
gpgcheck=1
gpgkey=https://repo.mysql.com/RPM-GPG-KEY-mysql-2022
EOF

  cat >/etc/yum.repos.d/mysql-connectors-community.repo <<EOF
[mysql-connectors-community]
name=MySQL Connectors Community
baseurl=http://repo.mysql.com/yum/mysql-connectors-community/el/8/x86_64/
enabled=1
gpgcheck=1
gpgkey=https://repo.mysql.com/RPM-GPG-KEY-mysql-2023
EOF
}

function add_mysql_packages() {
  DATAPROC_OPTIONAL_COMPONENTS+=(mysql)
  DATAPROC_COMMON_PACKAGES+=(mysql mysql-connector-j)
  DATAPROC_MASTER_EXCLUSIVE_SERVICES+=(mysql-server)
  PACKAGE_TO_SERVICE_NAME["mysql-server"]="${MYSQL_SERVICE}"
}

function lock_mysql_packages() {
  local -l version="${MYSQL_VERSION}.${MYSQL_SUBMINOR_VERSION}*"

  os_lock_package_to_specific_version mysql-community-server "${version}"
  os_lock_package_to_specific_version mysql-community-client "${version}"
  os_lock_package_to_specific_version mysql-community-common "${version}"
  os_lock_package_to_specific_version mysql-community-libs "${version}"
}

function create_config_sym_link() {
  if [[ ! -d /etc/mysql ]]; then
     mkdir /etc/mysql
  fi
  ln -s /etc/my.cnf /etc/mysql/my.cnf
  echo "Created a symlink for in /etc/mysql/my.cnf"
}

# TODO: Migrate setup repo part to mysql install script
setup_mysql_repo
add_mysql_packages

if [[ "${DATAPROC_IMAGE_TYPE}" == "standard" ]] &&
    ! is_version_at_least "${DATAPROC_IMAGE_VERSION}" "2.1" ; then
  # Locking mysql version to avoid upgrade to mysql version with Openssl 3.0 in
  # Dataproc 2.0 and 1.5 images.
  # TODO
  lock_mysql_packages
fi

create_config_sym_link
