#!/bin/bash

# This script is called by Spark workers to launch executors.

source /etc/environment
source "${BDUTIL_DIR}/components/shared/spark.sh"

set -euo pipefail

function get_executor_id() {
  local arg
  local executor_id_arg="false"
  for arg in "$@"; do
    if [[ '--executor-id' == "${arg}" ]]; then
      executor_id_arg="true"
    elif [[ "${executor_id_arg}" == "true" ]]; then
      echo "${arg}"
      return 0
    fi
  done
  echo "ERROR: --executor-id not found in '$*'"
  exit 1
}

function main() {
  local executor_id
  executor_id="$(get_executor_id "$@")"

  local container_name
  container_name="executor-${executor_id}-$(date +%Y%m%d%H%M%S)"

  local -r command=(
    /usr/bin/tini
    -s
    --
    "${BDUTIL_DIR}/spark-containerd-runner.sh"
    "${PWD}"
    "${container_name}"
    "$@")
  echo "Launching executor ${executor_id} with: ${command[*]}"
  "${command[@]}" >"${SPARK_LOG_DIR}/spark-${container_name}.log" 2>&1
}

main "$@"
